@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: StringUtils.cpp 1631 2008-02-02 22:25:30Z mapopa $
+  $Id: StringUtils.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -68,24 +68,36 @@ wxString std2wx(const std::string& input, wxMBConv* conv)
     return wxString(input.c_str(), *conv);
 }
 //-----------------------------------------------------------------------------
+wxString std2wxIdentifier(const std::string& input, wxMBConv* conv)
+{
+    if (input.empty())
+        return wxEmptyString;
+    if (!conv)
+        conv = wxConvCurrent;
+    // trim trailing whitespace
+    size_t last = input.find_last_not_of(" ");
+    return wxString(input.c_str(), *conv,
+        (last == std::string::npos) ? std::string::npos : last + 1);
+}
+//-----------------------------------------------------------------------------
 //! converts chars that have special meaning in HTML, so they get displayed
 wxString escapeHtmlChars(const wxString& input, bool processNewlines)
 {
     if (input.empty())
         return input;
     wxString result;
-    size_t start = 0, len = input.length();
-    while (start < len)
+    wxString::const_iterator start = input.begin();
+    while (start != input.end())
     {
-        size_t stop = start;
-        while (stop < len)
+        wxString::const_iterator stop = start;
+        while (stop != input.end())
         {
-            const wxChar c = input[stop];
+            const wxChar c = *stop;
             if (c == '&' || c == '<' || c == '>' || c == '"'
                 || (processNewlines && (c == '\r' || c == '\n')))
             {
                 if (stop > start)
-                    result += input.Mid(start, stop - start);
+                    result += wxString(start, stop);
                 if (c == '&')
                     result += wxT("&amp;");
                 else if (c == '<')
@@ -108,7 +120,7 @@ wxString escapeHtmlChars(const wxString& input, bool processNewlines)
             ++stop;
         }
         if (stop > start)
-            result += input.Mid(start, stop - start);
+            result += wxString(start, stop);
         start = stop;
     }
     return result;
@@ -161,73 +173,3 @@ wxString getHtmlCharset()
     return wxT("UTF-8");
 }
 //-----------------------------------------------------------------------------
-DatabaseToSystemCharsetConversion::DatabaseToSystemCharsetConversion()
-{
-    converterM = 0;
-}
-//-----------------------------------------------------------------------------
-DatabaseToSystemCharsetConversion::~DatabaseToSystemCharsetConversion()
-{
-    delete converterM;
-}
-//-----------------------------------------------------------------------------
-wxMBConv* DatabaseToSystemCharsetConversion::getConverter()
-{
-    if (converterM)
-        return converterM;
-    return wxConvCurrent;
-}
-//-----------------------------------------------------------------------------
-wxString DatabaseToSystemCharsetConversion::mapCharset(
-    const wxString& connectionCharset)
-{
-    wxString charset(connectionCharset.Upper().Trim());
-    charset.Trim(false);
-
-    // fixes hang when character set name empty (invalid encoding is returned)
-    if (charset.empty())
-        charset = wxT("NONE");
-
-    // Firebird charsets WIN125X need to be replaced with either
-    // WINDOWS125X or CP125X - we take the latter
-    if (charset.Mid(0, 5) == wxT("WIN12"))
-        return wxT("CP12") + charset.Mid(5);
-
-    // Firebird charsets ISO8859_X
-    if (charset.Mid(0, 8) == wxT("ISO8859_"))
-        return wxT("ISO-8859-") + charset.Mid(8);
-
-    // all other mappings need to be added here...
-    struct CharsetMapping { const wxChar* connCS; const wxChar* convCS; };
-    static const CharsetMapping mappings[] = {
-        { wxT("UTF8"), wxT("UTF-8") }, { wxT("UNICODE_FSS"), wxT("UTF-8") }
-    };
-    int mappingCount = sizeof(mappings) / sizeof(CharsetMapping);
-    for (int i = 0; i < mappingCount; i++)
-    {
-        if (mappings[i].connCS == charset)
-            return mappings[i].convCS;
-    }
-
-    return charset;
-}
-//-----------------------------------------------------------------------------
-void DatabaseToSystemCharsetConversion::setConnectionCharset(
-    const wxString& connectionCharset)
-{
-    if (connectionCharsetM != connectionCharset)
-    {
-        if (converterM)
-        {
-            delete converterM;
-            converterM = 0;
-        }
-
-        connectionCharsetM = connectionCharset;
-        wxFontEncoding fe = wxFontMapperBase::Get()->CharsetToEncoding(
-            mapCharset(connectionCharset), false);
-        if (fe != wxFONTENCODING_SYSTEM)
-            converterM = new wxCSConv(fe);
-    }
-}
-//-----------------------------------------------------------------------------
