@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: StringUtils.h 1631 2008-02-02 22:25:30Z mapopa $
+  $Id: StringUtils.h 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -36,6 +36,8 @@ class wxMBConv;
 //-----------------------------------------------------------------------------
 std::string wx2std(const wxString& input, wxMBConv* conv = wxConvCurrent);
 wxString std2wx(const std::string& input, wxMBConv* conv = wxConvCurrent);
+
+wxString std2wxIdentifier(const std::string& input, wxMBConv* conv);
 //-----------------------------------------------------------------------------
 //! converts chars that have special meaning in HTML, so they get displayed
 wxString escapeHtmlChars(const wxString& input, bool processNewlines = true);
@@ -44,20 +46,4 @@ wxString escapeHtmlChars(const wxString& input, bool processNewlines = true);
 //  conversion to UTF-8 is available, i.e. in non-Unicode build
 wxString getHtmlCharset();
 //-----------------------------------------------------------------------------
-// a helper class to manage the wxMBConv object necessary to translate from
-// and to the database connection charset
-class DatabaseToSystemCharsetConversion
-{
-private:
-    wxString connectionCharsetM;
-    wxMBConv* converterM;
-public:
-    DatabaseToSystemCharsetConversion();
-    ~DatabaseToSystemCharsetConversion();
-
-    wxMBConv* getConverter();
-    static wxString mapCharset(const wxString& connectionCharset);
-    void setConnectionCharset(const wxString& connectionCharset);
-};
-//-----------------------------------------------------------------------------
 #endif // FR_STRINGUTILS_H
