@@ -1,27 +1,27 @@
 /*
-Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
-Permission is hereby granted, free of charge, to any person obtaining
-a copy of this software and associated documentation files (the
-"Software"), to deal in the Software without restriction, including
-without limitation the rights to use, copy, modify, merge, publish,
-distribute, sublicense, and/or sell copies of the Software, and to
-permit persons to whom the Software is furnished to do so, subject to
-the following conditions:
+  Permission is hereby granted, free of charge, to any person obtaining
+  a copy of this software and associated documentation files (the
+  "Software"), to deal in the Software without restriction, including
+  without limitation the rights to use, copy, modify, merge, publish,
+  distribute, sublicense, and/or sell copies of the Software, and to
+  permit persons to whom the Software is furnished to do so, subject to
+  the following conditions:
 
-The above copyright notice and this permission notice shall be included
-in all copies or substantial portions of the Software.
+  The above copyright notice and this permission notice shall be included
+  in all copies or substantial portions of the Software.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: databasehandler.cpp 1629 2008-02-02 21:15:11Z mapopa $
+  $Id: databasehandler.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -81,7 +81,7 @@ bool DatabaseInfoHandler::handleURI(URI& uri)
 
     if (isEditSweep)
     {
-        long oldSweep = d->getInfo()->getSweep();
+        long oldSweep = d->getInfo().getSweep();
 
         while (true)
         {
@@ -108,15 +108,14 @@ bool DatabaseInfoHandler::handleURI(URI& uri)
             // Server.
             db->Disconnect();
             db->Connect();
-            d->getInfo()->loadInfo(&db);
-            d->notifyObservers();
+            d->loadInfo();
             break;
         }
     }
 
     if (isEditForcedWrites)
     {
-        bool forced = !d->getInfo()->getForcedWrites();
+        bool forced = !d->getInfo().getForcedWrites();
 
         // disconnect the database before changing SyncWrites. When the
         // database remains connected, you can set SyncWrites for about
@@ -131,8 +130,7 @@ bool DatabaseInfoHandler::handleURI(URI& uri)
 
         // load the database info because the value of forced writes been
         // changed.
-        d->getInfo()->loadInfo(&db);
-        d->notifyObservers();
+        d->loadInfo();
     }
 
     svc->Disconnect();
