@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: frutils.cpp 1630 2008-02-02 21:19:42Z mapopa $
+  $Id: frutils.cpp 1839 2009-03-23 21:17:45Z mghie $
 
 */
 
@@ -73,7 +73,8 @@ void adjustControlsMinWidth(list<wxWindow*> controls)
     }
 }
 //-----------------------------------------------------------------------------
-void readBlob(IBPP::Statement& st, int column, wxString& result)
+void readBlob(IBPP::Statement& st, int column, wxString& result,
+    wxMBConv* conv)
 {
     result = wxT("");
     if (st->IsNull(column))
@@ -101,7 +102,7 @@ void readBlob(IBPP::Statement& st, int column, wxString& result)
         readBuffer[size] = 0;
         resultBuffer += readBuffer;
     }
-    result = std2wx(resultBuffer);
+    result = std2wx(resultBuffer, conv);
     b->Close();
 }
 //-----------------------------------------------------------------------------
@@ -129,7 +130,15 @@ bool selectRelationColumnsIntoVector(Relation* t, wxWindow* parent, vector<wxStr
         columns.Add((*it)->getName_());
 
     wxArrayInt selected_columns;
-    if (!::wxGetMultipleChoices(selected_columns, _("Select one or more fields... (use ctrl key)"),  _("Table fields"), columns, parent))
+    bool ok = 
+#if wxCHECK_VERSION(2, 9, 0)
+    ::wxGetSelectedChoices(selected_columns,
+#else
+    ::wxGetMultipleChoices(selected_columns,
+#endif
+        _("Select one or more fields... (use ctrl key)"),  _("Table Fields"),
+        columns, parent) > 0;
+    if (!ok)
         return false;
 
     for (size_t i = 0; i < selected_columns.GetCount(); ++i)
@@ -137,26 +146,25 @@ bool selectRelationColumnsIntoVector(Relation* t, wxWindow* parent, vector<wxStr
         Identifier temp(columns[selected_columns[i]]);
         list.push_back(temp.getQuoted());
     }
-
     return true;
 }
 //-----------------------------------------------------------------------------
-bool connectDatabase(Database *db, wxWindow* parent,
+bool connectDatabase(Database* db, wxWindow* parent,
     ProgressDialog* progressdialog)
 {
     wxString pass(db->getDecryptedPassword());
-    if (pass.empty())
+    if (db->getAuthenticationMode().getAlwaysAskForPassword())
     {
+        // don't allow different username here
         UsernamePasswordDialog upd(wxGetActiveWindow(),
-            _("Database Credentials"), db->getUsername(), true, // don't allow different username
+            _("Database Credentials"), db->getUsername(), true,
             _("Please enter the the database user's password:"));
-        if (upd.ShowModal() == wxID_OK)
-            pass = upd.getPassword();
+        if (upd.ShowModal() != wxID_OK)
+            return false;
+        pass = upd.getPassword();
     }
-    if (pass.empty())
-        return false;
 
-    wxString caption(wxString::Format(wxT("Connecting with Database \"%s\""),
+    wxString caption(wxString::Format(_("Connecting to Database \"%s\""),
         db->getName_().c_str()));
     if (progressdialog)
     {
