@@ -1,27 +1,27 @@
 /*
-Copyright (c) 2004, 2005, 2006 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
-Permission is hereby granted, free of charge, to any person obtaining
-a copy of this software and associated documentation files (the
-"Software"), to deal in the Software without restriction, including
-without limitation the rights to use, copy, modify, merge, publish,
-distribute, sublicense, and/or sell copies of the Software, and to
-permit persons to whom the Software is furnished to do so, subject to
-the following conditions:
+  Permission is hereby granted, free of charge, to any person obtaining
+  a copy of this software and associated documentation files (the
+  "Software"), to deal in the Software without restriction, including
+  without limitation the rights to use, copy, modify, merge, publish,
+  distribute, sublicense, and/or sell copies of the Software, and to
+  permit persons to whom the Software is furnished to do so, subject to
+  the following conditions:
 
-The above copyright notice and this permission notice shall be included
-in all copies or substantial portions of the Software.
+  The above copyright notice and this permission notice shall be included
+  in all copies or substantial portions of the Software.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: AdvancedMessageDialog.cpp 1581 2007-12-05 21:36:54Z babuskov $
+  $Id: AdvancedMessageDialog.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -125,6 +125,15 @@ AdvancedMessageDialogButtonsOkCancel::AdvancedMessageDialogButtonsOkCancel(
     addNegativeButton(wxID_CANCEL, buttonCancelCaption);
 }
 //-----------------------------------------------------------------------------
+AdvancedMessageDialogButtonsYesNoCancel::
+    AdvancedMessageDialogButtonsYesNoCancel(const wxString buttonYesCaption,
+    const wxString buttonNoCaption, const wxString buttonCancelCaption)
+{
+    addAffirmativeButton(wxID_YES, buttonYesCaption);
+    addAlternateButton(wxID_NO, buttonNoCaption);
+    addNegativeButton(wxID_CANCEL, buttonCancelCaption);
+}
+//-----------------------------------------------------------------------------
 class TextWrapEngine
 {
 private:
@@ -226,7 +235,7 @@ wxSize TextWrapEngine::computeWrappedExtent(wxDC& dc, const wxString& text,
 {
     int textW = 0, textH = 0;
 
-	const wxChar* const pos = text.c_str();
+    const wxChar* const pos = text.c_str();
     const wxChar* p = text.c_str();
     const wxChar* pWrap = 0;
     const wxChar* r = p;
@@ -263,7 +272,7 @@ wxString TextWrapEngine::wrapLine(wxDC& dc, const wxString& text,
 {
     wxString result;
 
-	const wxChar* const pos = text.c_str();
+    const wxChar* const pos = text.c_str();
     const wxChar* p = text.c_str();
     const wxChar* pWrap = 0;
     const wxChar* r = p;
