@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: AdvancedSearchFrame.h 1631 2008-02-02 22:25:30Z mapopa $
+  $Id: AdvancedSearchFrame.h 1836 2009-02-14 11:22:13Z mghie $
 
 */
 #ifndef FR_ADVANCEDSEARCHFRAME_H
@@ -66,6 +66,7 @@ public:
 class MetadataItem;
 class AdjustableListCtrl;   // declaration in cpp file
 class MainFrame;
+class wxStyledTextCtrl;
 //-----------------------------------------------------------------------------
 class AdvancedSearchFrame : public BaseFrame, public Observer
 {
@@ -113,7 +114,7 @@ protected:
     wxPanel *top_splitter_panel;
     AdjustableListCtrl *listctrl_results;
     wxPanel *bottom_splitter_panel;
-    wxTextCtrl *stc_ddl;
+    wxStyledTextCtrl *stc_ddl;
 
 public:
     AdvancedSearchFrame(MainFrame *parent);
