@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: CommandIds.h 1733 2008-08-29 20:41:31Z mghie $
+  $Id: CommandIds.h 1836 2009-02-14 11:22:13Z mghie $
 
 */
 #ifndef FR_COMMANDIDS_H
@@ -34,13 +34,10 @@ namespace Cmds
         View_Editor = 401,
         View_Statistics,
         View_Data,
-        View_Split_view,
-        View_Toggle_view,
+        View_SplitView,
         View_Wrap_long_lines,
         View_Set_editor_font,
         Find_Selected_Object,
-        View_Focus_grid,
-        View_Focus_editor,
 
         // SQL History
         History_Search,
@@ -53,6 +50,12 @@ namespace Cmds
         Query_Execute_from_cursor,
         Query_Commit,
         Query_Rollback,
+        // next 4: order is important, because EVT_MENU_RANGE is used
+        Query_TransactionConcurrency,
+        Query_TransactionReadDirty,
+        Query_TransactionReadCommitted,
+        Query_TransactionConsistency,
+        Query_TransactionReadOnly,
 
         // SQL Data grid
         DataGrid_Insert_row,
@@ -83,7 +86,8 @@ namespace Cmds
         Menu_DropObject, Menu_ShowGeneratorValue, Menu_SetGeneratorValue,
         Menu_AddColumn, Menu_CreateTriggerForTable, Menu_RestoreIntoNew,
         Menu_MonitorEvents, Menu_GetServerVersion, Menu_AlterObject,
-        Menu_DropDatabase, Menu_DatabaseProperties, Menu_GenerateData,
+        Menu_DropDatabase, Menu_RecreateDatabase, Menu_DatabaseProperties,
+        Menu_GenerateData,
         Menu_CreateProcedureForTable, Menu_ExtractDatabaseDDL,
 
         // view menu
