@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: ContextMenuMetadataItemVisitor.cpp 1636 2008-02-17 22:53:37Z babuskov $
+  $Id: ContextMenuMetadataItemVisitor.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 //-----------------------------------------------------------------------------
@@ -78,9 +78,11 @@ void ContextMenuMetadataItemVisitor::visitDatabase(Database&)
     menuM->Append(Cmds::Menu_UnRegisterDatabase, _("&Unregister database"));
 
     // the actions submenu
-    actions->Append(Cmds::Menu_DropDatabase, _("Drop database"));
     actions->Append(Cmds::Menu_Backup, _("&Backup database..."));
     actions->Append(Cmds::Menu_Restore, _("Rest&ore database..."));
+    actions->AppendSeparator();
+    actions->Append(Cmds::Menu_RecreateDatabase, _("Recreate empty database"));
+    actions->Append(Cmds::Menu_DropDatabase, _("Drop database"));
 
     // the advanced submenu
     advanced->Append(Cmds::Menu_ShowConnectedUsers, _("&Show connected users"));
