@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: DataGeneratorFrame.cpp 1736 2008-09-12 22:47:37Z babuskov $
+  $Id: DataGeneratorFrame.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -262,9 +262,6 @@ DataGeneratorFrame::DataGeneratorFrame(wxWindow* parent, Database* db)
 {
     // until we find something better
     SetIcon(wxArtProvider::GetIcon(ART_Procedure, wxART_FRAME_ICON));
-
-    dbCharsetConversionM.setConnectionCharset(db->getConnectionCharset());
-
     SetTitle(_("Test Data Generator"));
     // prevent tree events from reaching the main frame
     // TODO: we need proper event handling for tree to allow multiple
@@ -811,12 +808,7 @@ void DataGeneratorFrame::OnLoadButtonClick(wxCommandEvent& WXUNUSED(event))
 {
     wxFileDialog fd(this, _("Select file to load"), wxT(""), wxT(""),
         _("XML files (*.xml)|*.xml|All files (*.*)|*.*"),
-#if wxCHECK_VERSION(2, 8, 0)
         wxFD_OPEN | wxFD_CHANGE_DIR);
-#else
-        wxOPEN | wxCHANGE_DIR);
-#endif
-
     if (wxID_OK != fd.ShowModal())
         return;
 
@@ -884,12 +876,7 @@ void DataGeneratorFrame::OnSaveButtonClick(wxCommandEvent& WXUNUSED(event))
 
     wxFileDialog fd(this, _("Select file to save"), wxT(""), wxT(""),
         _("XML files (*.xml)|*.xml|All files (*.*)|*.*"),
-#if wxCHECK_VERSION(2, 8, 0)
         wxFD_SAVE | wxFD_CHANGE_DIR | wxFD_OVERWRITE_PROMPT);
-#else
-        wxSAVE |wxCHANGE_DIR | wxOVERWRITE_PROMPT);
-#endif
-
     if (wxID_OK != fd.ShowModal())
         return;
 
@@ -981,11 +968,7 @@ void DataGeneratorFrame::OnFileButtonClick(wxCommandEvent& WXUNUSED(event))
 {
     wxFileDialog fd(this, _("Select file to load"), wxT(""), wxT(""),
         _("Text files (*.txt)|*.txt|All files (*.*)|*.*"),
-#if wxCHECK_VERSION(2, 8, 0)
         wxFD_OPEN | wxFD_CHANGE_DIR);
-#else
-        wxOPEN | wxCHANGE_DIR);
-#endif
     if (wxID_OK != fd.ShowModal())
         return;
 
@@ -1159,7 +1142,6 @@ void setFromFile(IBPP::Statement st, int param,
             break;
         }
         case IBPP::sdLargeint:
-#if wxCHECK_VERSION(2, 8, 0)
         {
             wxLongLong_t ll;
             if (!selected.ToLongLong(&ll))
@@ -1168,7 +1150,6 @@ void setFromFile(IBPP::Statement st, int param,
             st->Set(param, t);
             break;
         }
-#endif
         case IBPP::sdInteger:
         {
             long l;
@@ -1301,7 +1282,7 @@ void DataGeneratorFrame::setString(IBPP::Statement st, int param,
             start = p;
         }
     }
-    st->Set(param, wx2std(value, dbCharsetConversionM.getConverter()));
+    st->Set(param, wx2std(value, databaseM->getCharsetConverter()));
 }
 //-----------------------------------------------------------------------------
 // gs->range = x,x-y,...
