@@ -1,27 +1,27 @@
 /*
-Copyright (c) 2004, 2005, 2006 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
-Permission is hereby granted, free of charge, to any person obtaining
-a copy of this software and associated documentation files (the
-"Software"), to deal in the Software without restriction, including
-without limitation the rights to use, copy, modify, merge, publish,
-distribute, sublicense, and/or sell copies of the Software, and to
-permit persons to whom the Software is furnished to do so, subject to
-the following conditions:
+  Permission is hereby granted, free of charge, to any person obtaining
+  a copy of this software and associated documentation files (the
+  "Software"), to deal in the Software without restriction, including
+  without limitation the rights to use, copy, modify, merge, publish,
+  distribute, sublicense, and/or sell copies of the Software, and to
+  permit persons to whom the Software is furnished to do so, subject to
+  the following conditions:
 
-The above copyright notice and this permission notice shall be included
-in all copies or substantial portions of the Software.
+  The above copyright notice and this permission notice shall be included
+  in all copies or substantial portions of the Software.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
-IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
+  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+  TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: DatabaseRegistrationDialog.h 1305 2007-05-27 15:29:09Z mghie $
+  $Id: DatabaseRegistrationDialog.h 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -50,6 +50,8 @@ private:
     wxStaticText* label_dbpath;
     FileTextControl* text_ctrl_dbpath;
     wxButton* button_browse;
+    wxStaticText* label_authentication;
+    wxChoice* choice_authentication;
     wxStaticText* label_username;
     wxTextCtrl* text_ctrl_username;
     wxStaticText* label_password;
@@ -62,7 +64,6 @@ private:
     wxChoice* choice_pagesize;
     wxStaticText* label_dialect;
     wxChoice* choice_dialect;
-    wxCheckBox* checkbox_encrypted;
     wxButton* button_ok;
     wxButton* button_cancel;
 
@@ -70,8 +71,14 @@ private:
     void createControls();
     void layoutControls();
     void setControlsProperties();
+    void updateAuthenticationMode();
     void updateButtons();
     void updateIsDefaultName();
+
+    wxArrayString getAuthenticationChoices() const;
+    wxArrayString getDatabaseCharsetChoices() const;
+    wxArrayString getDatabaseDialectChoices() const;
+    wxArrayString getDatabasePagesizeChoices() const;
 protected:
     virtual const wxString getName() const;
     virtual bool getConfigStoresHeight() const;
@@ -90,9 +97,11 @@ private:
         ID_textcontrol_name,
         ID_textcontrol_username,
         ID_textcontrol_password,
-        ID_button_browse
+        ID_button_browse,
+        ID_choice_authentication
     };
 
+    void OnAuthenticationChange(wxCommandEvent& event);
     void OnBrowseButtonClick(wxCommandEvent& event);
     void OnNameChange(wxCommandEvent& event);
     void OnOkButtonClick(wxCommandEvent& event);
