@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: EventWatcherFrame.cpp 1631 2008-02-02 22:25:30Z mapopa $
+  $Id: EventWatcherFrame.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -331,11 +331,7 @@ void EventWatcherFrame::OnButtonLoadClick(wxCommandEvent& WXUNUSED(event))
 {
     wxFileDialog fd(this, _("Select file to load"), wxT(""), wxT(""),
         _("Text files (*.txt)|*.txt|All files (*.*)|*.*"),
-#if wxCHECK_VERSION(2, 8, 0)
         wxFD_OPEN | wxFD_CHANGE_DIR);
-#else
-        wxOPEN | wxCHANGE_DIR);
-#endif
     if (wxID_OK != fd.ShowModal())
         return;
 
@@ -357,12 +353,7 @@ void EventWatcherFrame::OnButtonSaveClick(wxCommandEvent& WXUNUSED(event))
 {
     wxFileDialog fd(this, _("Select file to save"), wxT(""), wxT(""),
         _("Text files (*.txt)|*.txt|All files (*.*)|*.*"),
-#if wxCHECK_VERSION(2, 8, 0)
         wxFD_SAVE | wxFD_CHANGE_DIR | wxFD_OVERWRITE_PROMPT);
-#else
-        wxSAVE |wxCHANGE_DIR | wxOVERWRITE_PROMPT);
-#endif
-
     if (wxID_OK != fd.ShowModal())
         return;
 
