@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: ExecuteSql.cpp 1729 2008-08-21 09:24:37Z mghie $
+  $Id: ExecuteSql.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 //-----------------------------------------------------------------------------
@@ -46,10 +46,6 @@ ExecuteSqlFrame* showSql(wxWindow* parent, const wxString& title,
 {
     ExecuteSqlFrame* eff = new ExecuteSqlFrame(parent, -1, title, database);
     eff->Show();
-    // bug reported 2008-08-19 by Valdir Marcos: status bar position wrong
-    // when ExecuteSqlFrame is created in maximized state
-    if (eff->IsMaximized())
-        eff->SendSizeEvent();
     eff->setSql(sql);
     return eff;
 }
