@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: FieldPropertiesDialog.cpp 1631 2008-02-02 22:25:30Z mapopa $
+  $Id: FieldPropertiesDialog.cpp 1840 2009-03-25 14:44:43Z babuskov $
 
 */
 
@@ -680,15 +680,21 @@ void FieldPropertiesDialog::updateSqlStatement()
 
     if (checkbox_trigger->IsChecked())
     {
+        // TODO: we could use BIGINT for FB 1.5 and above
         Identifier triggername(tableM->getName_() + wxT("_BI"));
         sql += wxT("SET TERM !! ;\n");
         sql += wxT("CREATE TRIGGER ") + triggername.getQuoted() + wxT(" FOR ")
-            + tableM->getQuotedName() + wxT("\n");
-        sql += wxT("ACTIVE BEFORE INSERT POSITION 0\nAS\nBEGIN\n");
-        sql += wxT("  IF (NEW.") + fNameSql + wxT(" IS NULL) THEN\n");
-        sql += wxT("    NEW.") + fNameSql + wxT(" = GEN_ID(")
-            + generator.getQuoted() + wxT(", 1);\n");
-        sql += wxT("END!!\n");
+            + tableM->getQuotedName() + wxT("\n")
+            + wxT("ACTIVE BEFORE INSERT POSITION 0\nAS\n")
+            + wxT("DECLARE VARIABLE tmp DECIMAL(18,0);\nBEGIN\n")
+            + wxT("  IF (NEW.") + fNameSql + wxT(" IS NULL) THEN\n")
+            + wxT("    NEW.") + fNameSql + wxT(" = GEN_ID(")
+            + generator.getQuoted() + wxT(", 1);\n")
+            + wxT("  ELSE\n  BEGIN\n    tmp = GEN_ID(") +
+            + generator.getQuoted() + wxT(", 0);\n    if (tmp < new.")
+            + fNameSql + wxT(") then\n      tmp = GEN_ID(")
+            + generator.getQuoted() + wxT(", new.") + fNameSql
+            + wxT("-tmp);\n  END\nEND!!\n");
         sql += wxT("SET TERM ; !!\n");
     }
 
