@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: InsertDialog.cpp 1719 2008-07-15 16:15:51Z mghie $
+  $Id: InsertDialog.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -292,7 +292,8 @@ InsertDialog::~InsertDialog()
 //-----------------------------------------------------------------------------
 void InsertDialog::set_properties()
 {
-    SetTitle(_("Insert Record(s) Into Table ") + tableNameM);
+    SetTitle(wxString::Format(_("Insert Record(s) Into Table \"%s\""),
+        tableNameM.c_str()));
     button_ok->SetDefault();
 }
 //-----------------------------------------------------------------------------
@@ -530,7 +531,8 @@ void InsertDialog::OnOkButtonClick(wxCommandEvent& WXUNUSED(event))
     storeValues();
     preloadSpecialColumns();
 
-    wxString stm = wxT("INSERT INTO ") + tableNameM + wxT(" (");
+    Identifier tableId(tableNameM);
+    wxString stm = wxT("INSERT INTO ") + tableId.getQuoted() + wxT(" (");
     wxString val = wxT(") VALUES (");
     bool first = true;
     for (std::vector<InsertColumnInfo>::iterator it = columnsM.begin();
@@ -559,13 +561,10 @@ void InsertDialog::OnOkButtonClick(wxCommandEvent& WXUNUSED(event))
         }
     }
 
-    DatabaseToSystemCharsetConversion dtscc;
-    dtscc.setConnectionCharset(databaseM->getConnectionCharset());
-
     IBPP::Statement st1 = IBPP::StatementFactory(statementM->DatabasePtr(),
         statementM->TransactionPtr());
     stm += val + wxT(")");
-    st1->Prepare(wx2std(stm, dtscc.getConverter()));
+    st1->Prepare(wx2std(stm, databaseM->getCharsetConverter()));
 
     // load blobs
     int index = 1;
