@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: MainFrame.cpp 1692 2008-04-27 17:36:02Z babuskov $
+  $Id: MainFrame.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -111,11 +111,7 @@ MainFrame::MainFrame(wxWindow* parent, int id, const wxString& title,
         const wxPoint& pos, const wxSize& size, long style)
     : BaseFrame(parent, id, title, pos, size, style, wxT("FlameRobin_main"))
 {
-#if wxCHECK_VERSION(2, 8, 0)
     wxArtProvider::Push(new ArtProvider);
-#else
-    wxArtProvider::PushProvider(new ArtProvider);
-#endif
 
     mainPanelM = new wxPanel(this);
     treeMainM = new DBHTreeControl(mainPanelM, wxDefaultPosition,
@@ -383,6 +379,7 @@ BEGIN_EVENT_TABLE(MainFrame, wxFrame)
     EVT_UPDATE_UI(Cmds::Menu_Disconnect, MainFrame::OnMenuUpdateIfDatabaseConnected)
     EVT_MENU(Cmds::Menu_Reconnect, MainFrame::OnMenuReconnect)
     EVT_UPDATE_UI(Cmds::Menu_Reconnect, MainFrame::OnMenuUpdateIfDatabaseConnected)
+    EVT_MENU(Cmds::Menu_RecreateDatabase, MainFrame::OnMenuRecreateDatabase)
     EVT_MENU(Cmds::Menu_DropDatabase, MainFrame::OnMenuDropDatabase)
     EVT_UPDATE_UI(Cmds::Menu_DropDatabase, MainFrame::OnMenuUpdateIfDatabaseConnected)
     EVT_MENU(Cmds::Menu_Query, MainFrame::OnMenuQuery)
@@ -489,19 +486,14 @@ void MainFrame::OnWindowMenuItem(wxCommandEvent& event)
 //-----------------------------------------------------------------------------
 void MainFrame::updateStatusbarText()
 {
-    wxStatusBar *sb = GetStatusBar();
-    if (!sb)
-        return;
-
-    Database* d = treeMainM->getSelectedDatabase();
-    if (d)
+    if (wxStatusBar* sb = GetStatusBar())
     {
-        wxString s = d->getUsername() + wxT("@") + d->getConnectionString()
-            + wxT(" (") + d->getConnectionCharset() + wxT(")");
-        sb->SetStatusText(s);
+        Database* d = treeMainM->getSelectedDatabase();
+        if (d)
+            sb->SetStatusText(d->getConnectionInfoString());
+        else
+            sb->SetStatusText(_("[No database selected]"));
     }
-    else
-        sb->SetStatusText(_("[No database selected]"));
 }
 //-----------------------------------------------------------------------------
 void MainFrame::OnTreeSelectionChanged(wxTreeEvent& WXUNUSED(event))
@@ -1473,6 +1465,48 @@ void MainFrame::OnMenuAlterObject(wxCommandEvent& WXUNUSED(event))
     showSql(this, wxString(_("Alter object")), db, sql);
 }
 //-----------------------------------------------------------------------------
+void MainFrame::OnMenuRecreateDatabase(wxCommandEvent& WXUNUSED(event))
+{
+    Database* d = treeMainM->getSelectedDatabase();
+
+    if (!checkValidDatabase(d))
+        return;
+
+    wxString msg(wxString::Format(
+        _("Are you sure you wish to recreate the database \"%s\"?"),
+        d->getName_().c_str()));
+    wxString secondary;
+    if (!d->isConnected())
+        secondary = _("First a connection to the database will be established. You may need to enter the password.\n");
+    secondary += _("The database will be dropped, and a new empty database will be created. All the data will be deleted, this is an irreversible action!");
+    if (wxOK == showQuestionDialog(this, msg, secondary,
+        AdvancedMessageDialogButtonsOkCancel(_("Recreate"))))
+    {
+        // it's unclear at this point whether the database does still exist
+        // try to connect to it, and if that succeeds then drop it
+        // ignore all errors along the way...
+        try
+        {
+            if (!d->isConnected())
+                connect();
+            if (d->isConnected())
+            {
+                d->drop();
+                d->disconnect(true);    // true = just remove the child nodes
+            }
+        }
+        catch(IBPP::Exception&) {}
+
+        // use the dialog as some information (charset and page size) is
+        // not necessarily available, and the user may want to change it too
+        DatabaseRegistrationDialog drd(this, _("Recreate Database"), true);
+        drd.setDatabase(d);
+        drd.setServer(d->getServer());
+        if (drd.ShowModal() == wxID_OK)
+            treeMainM->selectMetadataItem(d);
+    }
+}
+//-----------------------------------------------------------------------------
 void MainFrame::OnMenuDropDatabase(wxCommandEvent& WXUNUSED(event))
 {
     Database* d = treeMainM->getSelectedDatabase();
