@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: MetadataItemPropertiesFrame.cpp 1740 2008-09-13 21:27:12Z babuskov $
+  $Id: MetadataItemPropertiesFrame.cpp 1844 2009-04-06 19:08:21Z babuskov $
 
 */
 
@@ -41,10 +41,7 @@
 #include <wx/clipbrd.h>
 #include <wx/file.h>
 #include <wx/filedlg.h>
-
-#if wxCHECK_VERSION(2, 8, 0)
 #include <wx/tipwin.h>
-#endif
 
 #include <fstream>
 #include <iomanip>
@@ -79,11 +76,7 @@ MetadataItemPropertiesFrame::MetadataItemPropertiesFrame(wxWindow* parent,
 
     Database* d = object->findDatabase();
     if (d)  // server property page doesn't have a database, so don't crash
-    {
-        wxString s = d->getUsername() + wxT("@") + d->getConnectionString()
-            + wxT(" (") + d->getConnectionCharset() + wxT(")");
-        sb->SetStatusText(s);
-    }
+        sb->SetStatusText(d->getConnectionInfoString());
     else
         sb->SetStatusText(object->getPrintableName());
 
@@ -188,6 +181,8 @@ void MetadataItemPropertiesFrame::showPanel(wxWindow* panel,
         notebookM->SetSelection(pg);
 
     Show();
+    if (panel)
+        panel->SetFocus();
     Raise();
 }
 //-----------------------------------------------------------------------------
@@ -900,7 +895,7 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         if (!d)
             return;
 
-        htmlpage += d->getInfo()->getCreated();
+        htmlpage += d->getInfo().getCreated();
     }
     else if (cmd == wxT("default_charset"))
     {
@@ -916,7 +911,7 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         if (!d)
             return;
 
-        htmlpage += wxString() << d->getInfo()->getDialect();
+        htmlpage += wxString() << d->getInfo().getDialect();
     }
     else if (cmd == wxT("filesize"))
     {
@@ -924,10 +919,10 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         if (!d)
             return;
 
-        float size = (float)d->getInfo()->getPageSize() * d->getInfo()->getPages();
-        const float kilo = 1024.0;
-        const float mega = kilo * kilo;
-        const float giga = kilo * mega;
+        int64_t size = d->getInfo().getSizeInBytes();
+        const double kilo = 1024;
+        const double mega = kilo * kilo;
+        const double giga = kilo * mega;
         if (size >= giga)
             htmlpage += wxString::Format(wxT("%0.2fGB"), size / giga);
         else if (size >= mega)
@@ -944,7 +939,7 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         wxString okimage = wxT("<img src=\"") + config().getHtmlTemplatesPath() + wxT("ok.png\">");
         wxString ximage = wxT("<img src=\"") + config().getHtmlTemplatesPath() + wxT("redx.png\">");
 
-        htmlpage += (d->getInfo()->getForcedWrites() ? okimage : ximage);
+        htmlpage += (d->getInfo().getForcedWrites() ? okimage : ximage);
     }
     else if (cmd == wxT("fullpath"))
     {
@@ -960,7 +955,7 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         if (!d)
             return;
 
-        htmlpage += wxString() << d->getInfo()->getNextTransaction();
+        htmlpage += wxString() << d->getInfo().getNextTransaction();
     }
     else if (cmd == wxT("ods_version"))
     {
@@ -968,11 +963,11 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         if (!d)
             return;
 
-        htmlpage += wxString() << d->getInfo()->getODS();
-        if (d->getInfo()->getODSMinor())
+        htmlpage += wxString() << d->getInfo().getODS();
+        if (d->getInfo().getODSMinor())
         {
             htmlpage += wxT(".");
-            htmlpage += wxString() << d->getInfo()->getODSMinor();
+            htmlpage += wxString() << d->getInfo().getODSMinor();
         }
     }
     else if (cmd == wxT("oldest_transaction"))
@@ -981,7 +976,7 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         if (!d)
             return;
 
-        htmlpage += wxString() << d->getInfo()->getOldestTransaction();
+        htmlpage += wxString() << d->getInfo().getOldestTransaction();
     }
     else if (cmd == wxT("page_buffers"))
     {
@@ -989,7 +984,7 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         if (!d)
             return;
 
-        htmlpage += wxString() << d->getInfo()->getBuffers();
+        htmlpage += wxString() << d->getInfo().getBuffers();
     }
     else if (cmd == wxT("page_size"))
     {
@@ -997,7 +992,7 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         if (!d)
             return;
 
-        htmlpage += wxString() << d->getInfo()->getPageSize();
+        htmlpage += wxString() << d->getInfo().getPageSize();
     }
     else if (cmd == wxT("pages"))
     {
@@ -1005,14 +1000,14 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         if (!d)
             return;
 
-        htmlpage += wxString() << d->getInfo()->getPages();
+        htmlpage += wxString() << d->getInfo().getPages();
     }
     else if (cmd == wxT("read_only"))
     {
         Database* d = dynamic_cast<Database*>(object);
         if (!d)
             return;
-        if (d->getInfo()->getReadOnly())
+        if (d->getInfo().getReadOnly())
             htmlpage += wxT("true");
     else
             htmlpage += wxT("false");
@@ -1023,7 +1018,7 @@ void MetadataItemPropertiesPanel::processCommand(wxString cmd, MetadataItem *obj
         if (!d)
             return;
 
-        htmlpage += wxString() << d->getInfo()->getSweep();
+        htmlpage += wxString() << d->getInfo().getSweep();
     }
 }
 //-----------------------------------------------------------------------------
@@ -1213,12 +1208,10 @@ void MetadataItemPropertiesPanel::update()
     requestLoadPage(false);
 }
 //-----------------------------------------------------------------------------
-#if wxCHECK_VERSION(2, 8, 0)
 BEGIN_EVENT_TABLE(MetadataItemPropertiesPanel, wxPanel)
     EVT_HTML_CELL_HOVER(MetadataItemPropertiesPanel::HtmlWindowID,
         MetadataItemPropertiesPanel::OnHtmlCellHover)
 END_EVENT_TABLE()
-#endif
 //-----------------------------------------------------------------------------
 BEGIN_EVENT_TABLE(MetadataItemPropertiesFrame, BaseFrame)
     EVT_CLOSE(MetadataItemPropertiesFrame::OnClose)
@@ -1265,7 +1258,6 @@ void MetadataItemPropertiesPanel::OnIdle(wxIdleEvent& WXUNUSED(event))
     loadPage();
 }
 //-----------------------------------------------------------------------------
-#if wxCHECK_VERSION(2, 8, 0)
 void MetadataItemPropertiesPanel::OnHtmlCellHover(wxHtmlCellEvent& event)
 {
     wxHtmlCell *c = event.GetCell();
@@ -1293,7 +1285,6 @@ void MetadataItemPropertiesPanel::OnHtmlCellHover(wxHtmlCellEvent& event)
         tw->SetBoundingRect(r);
     }
 }
-#endif
 //-----------------------------------------------------------------------------
 //! PageHandler class
 class PageHandler: public URIHandler
