@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: RestoreFrame.cpp 1654 2008-03-19 14:38:07Z mghie $
+  $Id: RestoreFrame.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -405,11 +405,7 @@ void RestoreFrame::OnBrowseButtonClick(wxCommandEvent& WXUNUSED(event))
     wxString filename = ::wxFileSelector(_("Select Backup File"),
         origName.GetPath(), origName.GetFullName(), wxT("*.fbk"),
         _("Backup file (*.fbk, *.gbk)|*.fbk;*.gbk|All files (*.*)|*.*"),
-#if wxCHECK_VERSION(2, 8, 0)
         wxFD_OPEN, this);
-#else
-        wxOPEN, this);
-#endif
     if (!filename.empty())
         text_ctrl_filename->SetValue(filename);
 }
