@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: DBHTreeControl.cpp 1723 2008-07-23 12:04:56Z babuskov $
+  $Id: DBHTreeControl.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -334,7 +334,7 @@ void DBHTreeItemVisitor::setNodeProperties(MetadataItem* metadataItem)
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitColumn(Column& column)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&column));
+    setNodeProperties(&column);
     // only show first line of multiline text (for computed columns)
     size_t nl = nodeTextM.find_first_of(wxT("\n\r"));
     if (nl != wxString::npos)
@@ -358,7 +358,7 @@ void DBHTreeItemVisitor::visitColumn(Column& column)
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitDatabase(Database& database)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&database));
+    setNodeProperties(&database);
     // show different images for connected and disconnected databases
     if (database.isConnected())
         nodeImageIndexM = DBHTreeImageList::get().getImageIndex(ART_DatabaseConnected);
@@ -373,29 +373,29 @@ void DBHTreeItemVisitor::visitDatabase(Database& database)
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitDomain(Domain& domain)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&domain));
+    setNodeProperties(&domain);
     // skip autogenerated domains
     nodeVisibleM = !domain.isSystem();
 }
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitException(Exception& exception)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&exception));
+    setNodeProperties(&exception);
 }
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitFunction(Function& function)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&function));
+    setNodeProperties(&function);
 }
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitGenerator(Generator& generator)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&generator));
+    setNodeProperties(&generator);
 }
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitProcedure(Procedure& procedure)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&procedure));
+    setNodeProperties(&procedure);
     // make node caption bold when parameter data is loaded (even if no child)
     if (procedure.isParameterInfoLoaded())
         nodeTextBoldM = true;
@@ -405,17 +405,17 @@ void DBHTreeItemVisitor::visitProcedure(Procedure& procedure)
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitParameter(Parameter& parameter)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&parameter));
+    setNodeProperties(&parameter);
 }
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitRole(Role& role)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&role));
+    setNodeProperties(&role);
 }
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitRoot(Root& root)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&root));
+    setNodeProperties(&root);
     // make root node caption bold even if it has no registered servers
     nodeTextBoldM = true;
     // show Server nodes even though Root::getChildrenCount() returns 0
@@ -425,7 +425,7 @@ void DBHTreeItemVisitor::visitRoot(Root& root)
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitServer(Server& server)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&server));
+    setNodeProperties(&server);
     // make server node caption bold even if it has no registered databases
     nodeTextBoldM = true;
     // show Database nodes even though Server::getChildrenCount() returns 0
@@ -435,26 +435,26 @@ void DBHTreeItemVisitor::visitServer(Server& server)
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitTable(Table& table)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&table));
+    setNodeProperties(&table);
     // show Column nodes if Config setting is on
     showChildrenM = DBHTreeConfigCache::get().getShowColumns();
 }
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitTrigger(Trigger& trigger)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&trigger));
+    setNodeProperties(&trigger);
 }
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitView(View& view)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&view));
+    setNodeProperties(&view);
     // show Column nodes if Config setting is on
     showChildrenM = DBHTreeConfigCache::get().getShowColumns();
 }
 //-----------------------------------------------------------------------------
 void DBHTreeItemVisitor::visitMetadataItem(MetadataItem& metadataItem)
 {
-    setNodeProperties(dynamic_cast<MetadataItem*>(&metadataItem));
+    setNodeProperties(&metadataItem);
 }
 //-----------------------------------------------------------------------------
 // DBHTreeItem is a special kind of observer, which observes special kind
