@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: DataGrid.cpp 1733 2008-08-29 20:41:31Z mghie $
+  $Id: DataGrid.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -56,7 +56,7 @@
 #include "metadata/table.h"
 //-----------------------------------------------------------------------------
 DataGrid::DataGrid(wxWindow* parent, wxWindowID id)
-    : wxGrid(parent, id)
+    : wxGrid(parent, id), timerM(this, TIMER_ID), calculateSumM(true)
 {
     EnableEditing(true);
     SetColLabelValue(0, wxT(""));
@@ -136,7 +136,7 @@ void DataGrid::extendSelection(int direction)
     }
 }
 //-----------------------------------------------------------------------------
-void DataGrid::fetchData(wxMBConv* conv)
+void DataGrid::fetchData(bool readonly)
 {
     DataGridTable* table = getDataGridTable();
     if (!table)
@@ -144,7 +144,7 @@ void DataGrid::fetchData(wxMBConv* conv)
 
     wxBusyCursor bc;
     BeginBatch();
-    table->initialFetch(conv);
+    table->initialFetch(readonly);
 
     for (int i = 0; i < table->GetNumberCols(); i++)
     {
@@ -152,7 +152,7 @@ void DataGrid::fetchData(wxMBConv* conv)
         ca->SetAlignment(
             (table->isNumericColumn(i)) ? wxALIGN_RIGHT : wxALIGN_LEFT,
             wxALIGN_TOP);
-        if (table->isReadonlyColumn(i))
+        if (readonly || table->isReadonlyColumn(i))
         {
             ca->SetReadOnly(true);
             ca->SetBackgroundColour(table->getReadonlyColour());
@@ -193,16 +193,17 @@ void DataGrid::notifyIfUnfetchedData()
     }
 }
 //-----------------------------------------------------------------------------
-void DataGrid::showPopMenu(wxPoint cursorPos)
+void DataGrid::showPopupMenu(wxPoint cursorPos)
 {
-    wxMenu m(0);
+    SetFocus();
 
+    wxMenu m(0);
     // TODO: merge this with ExecuteSqlFrame's menu
     m.Append(Cmds::DataGrid_FetchAll, _("Fetch all records"));
     m.Append(Cmds::DataGrid_CancelFetchAll, _("Stop fetching all records"));
     m.AppendSeparator();
 
-    m.Append(wxID_COPY, _("Copy\tCtrl+C"));
+    m.Append(wxID_COPY, _("Copy"));
     m.Append(Cmds::DataGrid_Copy_as_insert, _("Copy as INSERT statements"));
     m.Append(Cmds::DataGrid_Copy_as_update, _("Copy as UPDATE statements"));
     m.Append(Cmds::DataGrid_Save_as_html, _("Save as HTML file..."));
@@ -317,7 +318,17 @@ void DataGrid::copyToCBAsInsert()
         //       - should probably refuse to work if not from one table
         //       - should probably refuse to create INSERT for "[...]"
         //       - table&PK info is available in DataGridRows::statementTablesM
-        wxString tableName = table->getTableName();
+        Identifier tableId(table->getTableName());
+
+        // load the (quoted if necessary) column names into an array
+        wxArrayString columnNames;
+        columnNames.Alloc(GetNumberCols());
+        for (int i = 0; i < GetNumberCols(); i++)
+        {
+            Identifier colId(GetColLabelValue(i));
+            columnNames.Add(colId.getQuoted());
+        }
+
         // NOTE: this has been reworked (compared to myDataGrid), because
         //       not all rows have necessarily the same fields selected
         wxString sRows;
@@ -331,9 +342,7 @@ void DataGrid::copyToCBAsInsert()
                 {
                     if (!sCols.IsEmpty())
                         sCols += wxT(", ");
-                    // NOTE: preloading the column names into a local wxString
-                    //       array might be a worthy optimization
-                    sCols += GetColLabelValue(j);
+                    sCols += columnNames[j];
                     if (!sValues.IsEmpty())
                         sValues += wxT(", ");
                     sValues += table->getCellValueForInsert(i, j);
@@ -343,7 +352,7 @@ void DataGrid::copyToCBAsInsert()
             }
             if (!sCols.IsEmpty())
             {
-                sRows += wxT("INSERT INTO ") + tableName + wxT(" (");
+                sRows += wxT("INSERT INTO ") + tableId.getQuoted() + wxT(" (");
                 sRows += sCols;
                 sRows += wxT(") VALUES (");
                 sRows += sValues;
@@ -377,7 +386,17 @@ void DataGrid::copyToCBAsUpdate()
         //       - should probably refuse to work if not from one table
         //       - should probably refuse to create UPDATE for "[...]"
         //       - we have this info in DataGridRows::statementTablesM
-        wxString tableName = table->getTableName();
+        Identifier tableId(table->getTableName());
+
+        // load the (quoted if necessary) column names into an array
+        wxArrayString columnNames;
+        columnNames.Alloc(GetNumberCols());
+        for (int i = 0; i < GetNumberCols(); i++)
+        {
+            Identifier colId(GetColLabelValue(i));
+            columnNames.Add(colId.getQuoted());
+        }
+
         wxString sRows;
         for (int i = 0; i < GetNumberRows(); i++)
         {
@@ -388,9 +407,7 @@ void DataGrid::copyToCBAsUpdate()
                 {
                     if (!str.IsEmpty())
                         str += wxT(", ");
-                    // NOTE: preloading the column names into a local wxString
-                    //       array might be a worthy optimization
-                    str += wxTextBuffer::GetEOL() + GetColLabelValue(j)
+                    str += wxTextBuffer::GetEOL() + columnNames[j]
                         + wxT(" = ") + table->getCellValueForInsert(i, j);
                 }
                 else
@@ -405,13 +422,13 @@ void DataGrid::copyToCBAsUpdate()
                 if (db)
                 {
                     t = dynamic_cast<Table *>(
-                        db->findByNameAndType(ntTable, tableName));
+                        db->findByNameAndType(ntTable, tableId.get()));
                 }
                 if (!t)
                 {
                     wxMessageBox(wxString::Format(
                         _("Table %s cannot be found in database."),
-                        tableName.c_str()),
+                        tableId.get().c_str()),
                         _("Error"), wxOK|wxICON_ERROR);
                     return;
                 }
@@ -444,8 +461,8 @@ void DataGrid::copyToCBAsUpdate()
                 }
                 // TODO: if (!pkc)   // WHERE all_cols = all_vals
 
-                sRows += wxT("UPDATE ") + tableName + wxT(" SET ") + str
-                    + wxTextBuffer::GetEOL() + wxT("WHERE ") + where
+                sRows += wxT("UPDATE ") + tableId.getQuoted() + wxT(" SET ")
+                    + str + wxTextBuffer::GetEOL() + wxT("WHERE ") + where
                     + wxT(";") + wxTextBuffer::GetEOL();
             }
         }
@@ -479,11 +496,7 @@ void DataGrid::saveAsCSV()
     wxString fname = ::wxFileSelector(_("Save data in selected cells as"),
         wxEmptyString, wxEmptyString, wxT("*.csv"),
         _("CSV files (*.csv)|*.csv|All files (*.*)|*.*"),
-#if wxCHECK_VERSION(2, 8, 0)
         wxFD_SAVE | wxFD_CHANGE_DIR | wxFD_OVERWRITE_PROMPT, this);
-#else
-        wxSAVE | wxCHANGE_DIR | wxOVERWRITE_PROMPT, this);
-#endif
     if (fname.empty())
         return;
 
@@ -571,11 +584,7 @@ void DataGrid::saveAsHTML()
     wxString fname = ::wxFileSelector(_("Save data in selected cells as"),
         wxEmptyString, wxEmptyString, wxT("*.html"),
         _("HTML files (*.html)|*.html|All files (*.*)|*.*"),
-#if wxCHECK_VERSION(2, 8, 0)
         wxFD_SAVE | wxFD_CHANGE_DIR | wxFD_OVERWRITE_PROMPT, this);
-#else
-        wxSAVE|wxCHANGE_DIR|wxOVERWRITE_PROMPT, this);
-#endif
     if (fname.empty())
         return;
 
@@ -686,14 +695,88 @@ BEGIN_EVENT_TABLE(DataGrid, wxGrid)
     EVT_GRID_CELL_RIGHT_CLICK(DataGrid::OnGridCellRightClick)
     EVT_GRID_LABEL_RIGHT_CLICK(DataGrid::OnGridLabelRightClick)
     EVT_GRID_EDITOR_CREATED(DataGrid::OnEditorCreated)
+    EVT_GRID_SELECT_CELL(DataGrid::OnGridCellSelected)
+    EVT_GRID_RANGE_SELECT(DataGrid::OnGridRangeSelected)
     //  EVT_GRID_EDITOR_HIDDEN( DataGrid::OnEditorHidden )
     EVT_KEY_DOWN(DataGrid::OnKeyDown)
+    EVT_TIMER(DataGrid::TIMER_ID, DataGrid::OnTimer)
 #ifdef __WXGTK__
     EVT_MOUSEWHEEL(DataGrid::OnMouseWheel)
     EVT_SCROLLWIN_THUMBRELEASE(DataGrid::OnThumbRelease)
 #endif
 END_EVENT_TABLE()
 //-----------------------------------------------------------------------------
+void DataGrid::OnGridCellSelected(wxGridEvent& event)
+{
+    timerM.Start(500, wxTIMER_ONE_SHOT);
+    event.Skip();
+}
+//-----------------------------------------------------------------------------
+void DataGrid::OnGridRangeSelected(wxGridRangeSelectEvent& event)
+{
+    timerM.Start(500, wxTIMER_ONE_SHOT);
+    event.Skip();
+}
+//-----------------------------------------------------------------------------
+DEFINE_EVENT_TYPE(wxEVT_FRDG_SUM)
+void DataGrid::OnTimer(wxTimerEvent& WXUNUSED(event))
+{
+    // calculate sum for all selected fields and show in status bar
+    DataGridTable* table = getDataGridTable();
+    if (!table || !calculateSumM)
+        return;
+
+    double sum = 0;
+    bool any = false;
+    bool alert = true;
+    wxStopWatch sw;;
+    for (int j = 0; j < GetNumberCols(); j++)
+    {
+        if (!table->isNumericColumn(j))
+            continue;
+        for (int i = 0; i < GetNumberRows(); i++)
+        {
+            if (IsInSelection(i, j))
+            {
+                double d;
+                wxString val = table->getCellValue(i, j);
+                if (val.ToDouble(&d))
+                {
+                    sum += d;
+                    any = true;
+                }
+            }
+            if (alert && sw.Time() > 4000)
+            {
+                AdvancedMessageDialogButtonsYesNoCancel amb(_("&Abort"),
+                    _("&Disable for this grid"), _("&Continue"));
+                int res = showQuestionDialog(this,
+                    _("Calculating the sum takes too long"),
+                    _("FlameRobin automatically calculates the sum of selected numeric values. However, the current calculation seems to be taking too long. Would you like to abort it?"),
+                    amb, config(), wxT("DIALOG_DisableGridSum"),
+                    _("Do not ask this question again"));
+                if (res == wxNO)
+                    calculateSumM = false;
+                if (res == wxYES || res == wxNO)
+                    return;
+                alert = false;
+            }
+        }
+    }
+
+    if (any)
+    {
+        // used in frame to update status bar
+        wxCommandEvent evt(wxEVT_FRDG_SUM, GetId());
+        wxString ss = wxString::Format(wxT("Sum: %f"), sum);
+        // strip trailing zeroes
+        ss.Truncate(1 + ss.find_last_not_of(wxT("0")));
+        ss.Truncate(1 + ss.find_last_not_of(wxT(".")));
+        evt.SetString(ss);
+        wxPostEvent(this, evt);
+    }
+}
+//-----------------------------------------------------------------------------
 void DataGrid::OnEditorCreated(wxGridEditorCreatedEvent& event)
 {
     wxTextCtrl *editor = dynamic_cast<wxTextCtrl *>(event.GetControl());
@@ -723,21 +806,32 @@ void DataGrid::OnEditorKeyDown(wxKeyEvent& event)
     event.Skip();
 }
 //-----------------------------------------------------------------------------
-void DataGrid::OnContextMenu(wxContextMenuEvent& WXUNUSED(event))
+void DataGrid::OnContextMenu(wxContextMenuEvent& event)
 {
+    if (IsCellEditControlEnabled())
+    {
+        event.Skip();
+        return;
+    }
+
     // this doesn't work properly when cell editor is active
     //  showPopMenu(event.GetPosition());
-    showPopMenu(ScreenToClient(::wxGetMousePosition()));
+    showPopupMenu(ScreenToClient(::wxGetMousePosition()));
 }
 //-----------------------------------------------------------------------------
 void DataGrid::OnGridCellRightClick(wxGridEvent& event)
 {
-    showPopMenu(event.GetPosition());
+    if (IsCellEditControlEnabled())
+    {
+        event.Skip();
+        return;
+    }
+    showPopupMenu(event.GetPosition());
 }
 //-----------------------------------------------------------------------------
 void DataGrid::OnGridLabelRightClick(wxGridEvent& WXUNUSED(event))
 {
-    showPopMenu(ScreenToClient(::wxGetMousePosition()));
+    showPopupMenu(ScreenToClient(::wxGetMousePosition()));
 }
 //-----------------------------------------------------------------------------
 /*
@@ -774,22 +868,12 @@ void DataGrid::OnKeyDown(wxKeyEvent& event)
 {
     if (event.GetKeyCode() == WXK_SPACE)
     {
-#if wxCHECK_VERSION(2, 8, 0)
         if (event.GetModifiers() == wxMOD_CONTROL)
-#else
-        if (event.ControlDown() && !event.AltDown() && !event.ShiftDown()
-            && !event.MetaDown())
-#endif
         {
             extendSelection(wxVERTICAL);
             return;
         }
-#if wxCHECK_VERSION(2, 8, 0)
         if (event.GetModifiers() == wxMOD_SHIFT)
-#else
-        if (event.ShiftDown() && !event.AltDown() && !event.ControlDown()
-            && !event.MetaDown())
-#endif
         {
             extendSelection(wxHORIZONTAL);
             return;
