@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: DataGrid.h 1631 2008-02-02 22:25:30Z mapopa $
+  $Id: DataGrid.h 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -32,31 +32,43 @@
 #include <wx/grid.h>
 
 class DataGridTable;
+//-----------------------------------------------------------------------------
+BEGIN_DECLARE_EVENT_TYPES()
+    // this event is sent when selection is changed and values are summed up
+    DECLARE_LOCAL_EVENT_TYPE(wxEVT_FRDG_SUM, 44)
+END_DECLARE_EVENT_TYPES()
 //----------------------------------------------------------------------
 class DataGrid: public wxGrid
 {
 private:
+    wxTimer timerM;
+    enum { TIMER_ID = 3333 };
+    bool calculateSumM;
+
     void copyToClipboard(const wxString cbText);
     void extendSelection(int direction);
     void notifyIfUnfetchedData();
-    void showPopMenu(wxPoint cursorPos);
+    void showPopupMenu(wxPoint cursorPos);
     void updateRowHeights();
 public:
     DataGrid(wxWindow* parent, wxWindowID id);
     ~DataGrid();
 
     DataGridTable* getDataGridTable();
-    void fetchData(wxMBConv* conv);
+    void fetchData(bool readonly);
 private:
     void OnContextMenu(wxContextMenuEvent& event);
     void OnGridCellRightClick(wxGridEvent& event);
+    void OnGridCellSelected(wxGridEvent& event);
     void OnGridLabelRightClick(wxGridEvent& event);
+    void OnGridRangeSelected(wxGridRangeSelectEvent& event);
     void OnIdle(wxIdleEvent& event);
     void OnKeyDown(wxKeyEvent& event);
     void OnMouseWheel(wxMouseEvent& event);
     void OnThumbRelease(wxScrollWinEvent& event);
     void OnEditorCreated(wxGridEditorCreatedEvent& event);
     void OnEditorKeyDown(wxKeyEvent& event);
+    void OnTimer(wxTimerEvent& event);
     DECLARE_EVENT_TABLE()
 public:
     void copyToCB();
