@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: DataGridRows.cpp 1744 2008-09-15 11:14:06Z babuskov $
+  $Id: DataGridRows.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -633,14 +633,12 @@ void Int64ColumnDef::setFromString(DataGridRowBuffer* buffer,
 {
     wxASSERT(buffer);
 
-#if wxCHECK_VERSION(2, 8, 0)
     wxLongLong_t ll;
     if (source.ToLongLong(&ll))
     {
         buffer->setValue(offsetM, (int64_t)ll);
         return;
     }
-#endif
 
     // perhaps underlying library doesn't support 64bit, we try 32:
     long l;
@@ -1300,9 +1298,10 @@ class StringColumnDef : public ResultsetColumnDef
 {
 private:
     unsigned indexM;
+    int charSizeM;
 public:
     StringColumnDef(const wxString& name, unsigned stringIndex, bool readOnly,
-        bool nullable);
+        bool nullable, int charSize);
     virtual unsigned getIndex();
     virtual wxString getAsFirebirdString(DataGridRowBuffer* buffer);
     virtual wxString getAsString(DataGridRowBuffer* buffer);
@@ -1314,8 +1313,9 @@ public:
 };
 //-----------------------------------------------------------------------------
 StringColumnDef::StringColumnDef(const wxString& name, unsigned stringIndex,
-    bool readOnly, bool nullable)
-    : ResultsetColumnDef(name, readOnly, nullable), indexM(stringIndex)
+    bool readOnly, bool nullable, int charSize)
+    : ResultsetColumnDef(name, readOnly, nullable), indexM(stringIndex),
+      charSizeM(charSize)
 {
 }
 //-----------------------------------------------------------------------------
@@ -1358,20 +1358,25 @@ void StringColumnDef::setValue(DataGridRowBuffer* buffer, unsigned col,
     wxASSERT(buffer);
     std::string value;
     statement->Get(col, value);
-    if (statement->ColumnSubtype(col) != 1)
-        buffer->setString(indexM, std2wx(value, converter));
-    else    // charset OCTETS
+    if (statement->ColumnSubtype(col) == 1)   // charset OCTETS
     {
         wxString val;
         for (std::string::size_type p = 0; p < value.length(); p++)
             val += wxString::Format(wxT("%02x"), uint8_t(value[p]));
         buffer->setString(indexM, val);
     }
+    else
+    {
+        wxString val(std2wx(value, converter));
+        if (val.Length() > size_t(charSizeM))
+            val.Truncate(charSizeM);
+        buffer->setString(indexM, val);
+    }
 }
 //-----------------------------------------------------------------------------
 // DataGridRows class
-DataGridRows::DataGridRows(Database *db)
-    : bufferSizeM(0), databaseM(db)
+DataGridRows::DataGridRows(Database* db)
+    : bufferSizeM(0), databaseM(db), readOnlyM(false)
 {
 }
 //-----------------------------------------------------------------------------
@@ -1392,8 +1397,7 @@ void DataGridRows::addRow(DataGridRowBuffer* buffer)
     buffersM.push_back(buffer);
 }
 //-----------------------------------------------------------------------------
-void DataGridRows::addRow(const IBPP::Statement& statement,
-    wxMBConv* converter)
+void DataGridRows::addRow(const IBPP::Statement& statement)
 {
     DataGridRowBuffer* buffer = new DataGridRowBuffer(columnDefsM.size());
     // if anything fails, make sure we release the memory
@@ -1409,7 +1413,10 @@ void DataGridRows::addRow(const IBPP::Statement& statement,
             bool isNull = statement->IsNull(colIBPP);
             buffer->setFieldNull(col, isNull);
             if (!isNull)
-                columnDefsM[col]->setValue(buffer, colIBPP, statement, converter);
+            {
+                columnDefsM[col]->setValue(buffer, colIBPP, statement,
+                    databaseM->getCharsetConverter());
+            }
         }
         while (col > 0);
     }
@@ -1467,9 +1474,12 @@ bool DataGridRows::canRemoveRow(size_t row)
             {
                 for (int c2 = 1; c2 <= statementM->Columns(); ++c2)
                 {
-                    if ((*ci) != std2wx(statementM->ColumnName(c2)))
+                    wxString cn(std2wxIdentifier(statementM->ColumnName(c2),
+                        databaseM->getCharsetConverter()));
+                    if ((*ci) != cn)
                         continue;
-                    wxString tn(std2wx(statementM->ColumnTable(c2)));
+                    wxString tn(std2wxIdentifier(statementM->ColumnTable(c2),
+                        databaseM->getCharsetConverter()));
                     if (tn == (*it).first && buffersM[row]->isFieldNA(c2-1))
                     {
                         tableok = false;
@@ -1534,7 +1544,8 @@ bool DataGridRows::removeRows(size_t from, size_t count, wxString& stm)
     while (count--)
     {
         i2 = it;
-        it--;
+        if (it != buffersM.begin ())//Prevents it from going before the first one
+          it--;
         (*i2)->setIsDeleted(true);
     }
     return true;
@@ -1557,8 +1568,8 @@ wxString DataGridRows::getRowFieldName(unsigned col)
     return wxEmptyString;
 }
 //-----------------------------------------------------------------------------
-void checkColumnsPresent(const IBPP::Statement& statement,
-    UniqueConstraint** locator)
+void checkColumnsPresent(const Database* database,
+    const IBPP::Statement& statement, UniqueConstraint** locator)
 {
     wxString tableName = (*locator)->getTable()->getName_();
     for (ColumnConstraint::const_iterator ci = (*locator)->begin(); ci !=
@@ -1567,8 +1578,10 @@ void checkColumnsPresent(const IBPP::Statement& statement,
         bool found = false;
         for (int c2 = 1; c2 <= statement->Columns(); ++c2)
         {
-            wxString cn(std2wx(statement->ColumnName(c2)));
-            wxString tn(std2wx(statement->ColumnTable(c2)));
+            wxString cn(std2wxIdentifier(statement->ColumnName(c2),
+                database->getCharsetConverter()));
+            wxString tn(std2wxIdentifier(statement->ColumnTable(c2),
+                database->getCharsetConverter()));
             if (cn == (*ci) && tn == tableName)
             {
                 found = true;
@@ -1589,6 +1602,12 @@ void checkColumnsPresent(const IBPP::Statement& statement,
 void DataGridRows::getColumnInfo(Database *db, unsigned col, bool& readOnly,
     bool& nullable)
 {
+    if (readOnlyM) // read-only transaction
+    {
+        readOnly = true;
+        return;
+    }
+
     if (statementM->ColumnType(col) == IBPP::sdString
         && statementM->ColumnSubtype(col) == 1) // charset OCTETS
     {                       // TODO: to make those editable, we need to
@@ -1596,7 +1615,8 @@ void DataGridRows::getColumnInfo(Database *db, unsigned col, bool& readOnly,
         return;             // probably be done together with BLOB support
     }
 
-    wxString tabName(std2wx(statementM->ColumnTable(col)));
+    wxString tabName(std2wxIdentifier(statementM->ColumnTable(col),
+        databaseM->getCharsetConverter()));
     Table *t = dynamic_cast<Table *>(db->findRelation(Identifier(tabName)));
     if (!t)
     {
@@ -1613,7 +1633,7 @@ void DataGridRows::getColumnInfo(Database *db, unsigned col, bool& readOnly,
     {
         locator = t->getPrimaryKey();
         if (locator)    // check if this PK is usable (all fields present)
-            checkColumnsPresent(statementM, &locator);
+            checkColumnsPresent(databaseM, statementM, &locator);
         if (!locator)   // PK not present or not usable, try UNQ
         {
             std::vector<UniqueConstraint> *uq = t->getUniqueConstraints();
@@ -1623,7 +1643,7 @@ void DataGridRows::getColumnInfo(Database *db, unsigned col, bool& readOnly,
                     ui != uq->end(); ++ui)
                 {
                     locator = &(*ui);
-                    checkColumnsPresent(statementM, &locator);
+                    checkColumnsPresent(databaseM, statementM, &locator);
                     if (locator)
                         break;
                 }
@@ -1635,7 +1655,7 @@ void DataGridRows::getColumnInfo(Database *db, unsigned col, bool& readOnly,
             uc.columnsM.push_back(wxT("DB_KEY"));
             uc.setParent(t);
             locator = &uc;
-            checkColumnsPresent(statementM, &locator);
+            checkColumnsPresent(databaseM, statementM, &locator);
             if (locator)    // DB_KEY present
             {
                 dbKeysM.push_back(uc);
@@ -1650,7 +1670,8 @@ void DataGridRows::getColumnInfo(Database *db, unsigned col, bool& readOnly,
     nullable = false;
     if (!readOnly)  // table is not RO, but column might be, so we search
     {
-        wxString cn(std2wx(statementM->ColumnName(col)));
+        wxString cn(std2wxIdentifier(statementM->ColumnName(col),
+            databaseM->getCharsetConverter()));
         Column *c = 0;
         t->checkAndLoadColumns();
         for (MetadataCollection<Column>::iterator it = t->begin();
@@ -1676,7 +1697,7 @@ void DataGridRows::getColumnInfo(Database *db, unsigned col, bool& readOnly,
     );*/
 }
 //-----------------------------------------------------------------------------
-bool DataGridRows::initialize(const IBPP::Statement& statement, Database *db)
+bool DataGridRows::initialize(const IBPP::Statement& statement)
 {
     statementM = statement;
 
@@ -1694,11 +1715,15 @@ bool DataGridRows::initialize(const IBPP::Statement& statement, Database *db)
     for (unsigned col = 1; col <= colCount; ++col)
     {
         bool readOnly, nullable;
-        getColumnInfo(db, col, readOnly, nullable);
+        getColumnInfo(databaseM, col, readOnly, nullable);
 
-        wxString colName(std2wx(statement->ColumnAlias(col)));
+        wxString colName(std2wx(statement->ColumnAlias(col),
+            databaseM->getCharsetConverter()));
         if (colName.empty())
-            colName = std2wx(statement->ColumnName(col));
+        {
+            colName = std2wx(statement->ColumnName(col),
+                databaseM->getCharsetConverter());
+        }
 
         IBPP::SDT type = statement->ColumnType(col);
         if (statement->ColumnScale(col) > 0)
@@ -1737,9 +1762,16 @@ bool DataGridRows::initialize(const IBPP::Statement& statement, Database *db)
                     break;
 
                 case IBPP::sdString:
-                    columnDef = new StringColumnDef(colName, stringIndex, readOnly, nullable);
+                {
+                    CharacterSet cs = databaseM->getCharsetById(statement->ColumnSubtype(col));
+                    int bpc = cs.getBytesPerChar();
+                    int size = statement->ColumnSize(col);
+                    if (bpc)
+                        size /= bpc;
+                    columnDef = new StringColumnDef(colName, stringIndex, readOnly, nullable, size);
                     ++stringIndex;
                     break;
+                }
                 case IBPP::sdBlob:
                     columnDef = new BlobColumnDef(colName, readOnly, nullable, stringIndex, blobIndex, statement->ColumnSubtype(col) == 1);
                     ++blobIndex;    // stores blob handle
@@ -1779,7 +1811,7 @@ bool DataGridRows::getFieldInfo(unsigned row, unsigned col,
         return false;
     info.rowInserted = buffersM[row]->isInserted();
     info.rowDeleted = buffersM[row]->isDeleted();
-    info.fieldReadOnly = info.rowDeleted
+    info.fieldReadOnly = readOnlyM || info.rowDeleted
         || isColumnReadonly(col) || isFieldReadonly(row, col);
     info.fieldModified = !info.rowDeleted
         && buffersM[row]->isFieldModified(col);
@@ -1803,7 +1835,8 @@ bool DataGridRows::isFieldReadonly(unsigned row, unsigned col)
 
     // TODO: this needs to be cached too
 
-    wxString table(std2wx(statementM->ColumnTable(col+1)));
+    wxString table(std2wxIdentifier(statementM->ColumnTable(col + 1),
+        databaseM->getCharsetConverter()));
     std::map<wxString, UniqueConstraint *>::iterator it =
         statementTablesM.find(table);
     if (it == statementTablesM.end() || (*it).second == 0)
@@ -1815,9 +1848,12 @@ bool DataGridRows::isFieldReadonly(unsigned row, unsigned col)
     {
         for (int c2 = 1; c2 <= statementM->Columns(); ++c2)
         {
-            if ((*ci) != std2wx(statementM->ColumnName(c2)))
+            wxString cn(std2wxIdentifier(statementM->ColumnName(c2),
+                databaseM->getCharsetConverter()));
+            if ((*ci) != cn)
                 continue;
-            wxString tn(std2wx(statementM->ColumnTable(c2)));
+            wxString tn(std2wxIdentifier(statementM->ColumnTable(c2),
+                databaseM->getCharsetConverter()));
             if (tn == table && buffersM[row]->isFieldNA(c2-1))
                 return true;
         }
@@ -1861,8 +1897,10 @@ IBPP::Statement DataGridRows::addWhere(UniqueConstraint* uq, wxString& stm,
         }
         for (int c2 = 1; c2 <= statementM->Columns(); ++c2)
         {
-            wxString cn(std2wx(statementM->ColumnName(c2)));
-            wxString tn(std2wx(statementM->ColumnTable(c2)));
+            wxString cn(std2wxIdentifier(statementM->ColumnName(c2),
+                databaseM->getCharsetConverter()));
+            wxString tn(std2wxIdentifier(statementM->ColumnTable(c2),
+                databaseM->getCharsetConverter()));
             if (cn == (*ci) && tn == table) // found it, add to WHERE list
             {
                 if (buffer->isFieldNA(c2-1))
@@ -1877,18 +1915,17 @@ IBPP::Statement DataGridRows::addWhere(UniqueConstraint* uq, wxString& stm,
         }
     }
 
-    DatabaseToSystemCharsetConversion dtscc;
-    dtscc.setConnectionCharset(databaseM->getConnectionCharset());
-
     IBPP::Statement st = IBPP::StatementFactory(statementM->DatabasePtr(),
         statementM->TransactionPtr());
-    st->Prepare(wx2std(stm, dtscc.getConverter()));
+    st->Prepare(wx2std(stm, databaseM->getCharsetConverter()));
     if (dbkey)  // find the column and set the parameter
     {
         for (int c2 = 1; c2 <= statementM->Columns(); ++c2)
         {
-            wxString cn(std2wx(statementM->ColumnName(c2)));
-            wxString tn(std2wx(statementM->ColumnTable(c2)));
+            wxString cn(std2wxIdentifier(statementM->ColumnName(c2),
+                databaseM->getCharsetConverter()));
+            wxString tn(std2wxIdentifier(statementM->ColumnTable(c2),
+                databaseM->getCharsetConverter()));
             if (cn == wxT("DB_KEY") && tn == table)
             {
                 DBKeyColumnDef *dbk =
@@ -1950,16 +1987,19 @@ void DataGridRows::importBlobFile(const wxString& filename, unsigned row,
     if (pi)
         pi->initProgress(_("Loading..."), fl.Length()); // wxFileOffset
 
-    wxString table(std2wx(statementM->ColumnTable(col+1)));
-    wxString stm = wxT("UPDATE ") + Identifier(table).getQuoted()
-        + wxT(" SET ")
-        + Identifier(std2wx(statementM->ColumnName(col+1))).getQuoted()
+    wxString tn(std2wxIdentifier(statementM->ColumnTable(col + 1),
+        databaseM->getCharsetConverter()));
+    wxString cn(std2wxIdentifier(statementM->ColumnName(col + 1),
+        databaseM->getCharsetConverter()));
+        
+    wxString stm = wxT("UPDATE ") + Identifier(tn).getQuoted()
+        + wxT(" SET ") + Identifier(cn).getQuoted()
         + wxT(" = ? WHERE ");
     std::map<wxString, UniqueConstraint *>::iterator it =
-        statementTablesM.find(table);
+        statementTablesM.find(tn);
     if (it == statementTablesM.end() || (*it).second == 0)
         throw FRError(_("Blob table not found."));
-    IBPP::Statement st = addWhere((*it).second, stm, table, buffersM[row]);
+    IBPP::Statement st = addWhere((*it).second, stm, tn, buffersM[row]);
     IBPP::Blob b = IBPP::BlobFactory(st->DatabasePtr(),
         st->TransactionPtr());
     b->Create();
@@ -2026,10 +2066,12 @@ wxString DataGridRows::setFieldValue(unsigned row, unsigned col,
         }
 
         // run the UPDATE statement
-        wxString table(std2wx(statementM->ColumnTable(col+1)));
-        wxString stm = wxT("UPDATE ") + Identifier(table).getQuoted()
-            + wxT(" SET ")
-            + Identifier(std2wx(statementM->ColumnName(col+1))).getQuoted();
+        wxString tn(std2wxIdentifier(statementM->ColumnTable(col + 1),
+            databaseM->getCharsetConverter()));
+        wxString cn(std2wxIdentifier(statementM->ColumnName(col + 1),
+            databaseM->getCharsetConverter()));
+        wxString stm = wxT("UPDATE ") + Identifier(tn).getQuoted()
+            + wxT(" SET ") + Identifier(cn).getQuoted();
         if (newIsNull)
             stm += wxT(" = NULL WHERE ");
         else
@@ -2040,14 +2082,14 @@ wxString DataGridRows::setFieldValue(unsigned row, unsigned col,
         }
 
         std::map<wxString, UniqueConstraint *>::iterator it =
-            statementTablesM.find(table);
+            statementTablesM.find(tn);
 
         // MB: please do not remove this check. Although it is not needed,
         //     it helped me detect some subtle bugs much easier
         if (it == statementTablesM.end() || (*it).second == 0)
             throw FRError(_("This column should not be editable"));
 
-        IBPP::Statement st = addWhere((*it).second, stm, table, oldRecord);
+        IBPP::Statement st = addWhere((*it).second, stm, tn, oldRecord);
         st->Execute();
         delete oldRecord;
         return stm;
