@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: DataGridRows.h 1677 2008-04-07 21:01:06Z babuskov $
+  $Id: DataGridRows.h 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -81,7 +81,8 @@ struct DataGridFieldInfo
 class DataGridRows
 {
 private:
-    Database *databaseM;
+    Database* databaseM;
+    const bool readOnlyM;
     IBPP::Statement statementM;
     std::vector<ResultsetColumnDef*> columnDefsM;
     std::vector<DataGridRowBuffer*> buffersM;
@@ -98,12 +99,12 @@ public:
     DataGridRows(Database* db);
     ~DataGridRows();
 
-    void addRow(const IBPP::Statement& statement, wxMBConv* converter);
+    void addRow(const IBPP::Statement& statement);
     void clear();
     unsigned getRowCount();
     unsigned getRowFieldCount();
     wxString getRowFieldName(unsigned col);
-    bool initialize(const IBPP::Statement& statement, Database* db);
+    bool initialize(const IBPP::Statement& statement);
 
     bool isColumnNumeric(unsigned col);
     bool isColumnReadonly(unsigned col);
