@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: DataGridTable.cpp 1677 2008-04-07 21:01:06Z babuskov $
+  $Id: DataGridTable.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -71,11 +71,7 @@ RgbHsvConversion::RgbHsvConversion(const wxColour& colour)
     redM = colour.Red() / 255.0;
     greenM = colour.Green() / 255.0;
     blueM = colour.Blue() / 255.0;
-#if wxCHECK_VERSION(2, 8, 0)
     rgbValidM = colour.IsOk();
-#else
-    rgbValidM = colour.Ok();
-#endif
     hueM = 0.0;
     satM = 0.0;
     valM = 0.0;
@@ -202,12 +198,13 @@ void RgbHsvConversion::setValue(float value)
     }
 }
 //-----------------------------------------------------------------------------
-DataGridTable::DataGridTable(IBPP::Statement& s, Database *db)
+DataGridTable::DataGridTable(IBPP::Statement& s, Database* db)
     : wxGridTableBase(), statementM(s), databaseM(db), nullFlagM(false),
-      rowsM(db)
+        rowsM(db)
 {
     allRowsFetchedM = false;
     fetchAllRowsM = false;
+    readOnlyM = false;
     canInsertRowsIsSetM = false;
     canInsertRowsM = false;
     config().getValue(wxT("GridFetchAllRecords"), fetchAllRowsM);
@@ -262,7 +259,7 @@ void DataGridTable::Clear()
 //-----------------------------------------------------------------------------
 void DataGridTable::fetchOne()
 {
-    rowsM.addRow(statementM, charsetConverterM);
+    rowsM.addRow(statementM);
     allRowsFetchedM = true;
 
     if (GetView())   // notify the grid
@@ -307,7 +304,7 @@ void DataGridTable::fetch()
         }
         if (allRowsFetchedM)
             break;
-        rowsM.addRow(statementM, charsetConverterM);
+        rowsM.addRow(statementM);
 
         if (!initial && (::wxGetLocalTimeMillis() - startms > 100))
             break;
@@ -352,9 +349,9 @@ wxGridCellAttr* DataGridTable::GetAttr(int row, int col,
     if (!rowsM.getFieldInfo(row, col, info))
         return wxGridTableBase::GetAttr(row, col, kind);
 
-    bool useAttri = info.rowInserted || info.rowDeleted || info.fieldReadOnly
-        || info.fieldModified || info.fieldNull || info.fieldNA
-        || info.fieldNumeric;
+    bool useAttri = readOnlyM || info.rowInserted || info.rowDeleted
+        || info.fieldReadOnly || info.fieldModified || info.fieldNull
+        || info.fieldNA || info.fieldNumeric;
     if (!useAttri)
         return wxGridTableBase::GetAttr(row, col, kind);
 
@@ -374,7 +371,7 @@ wxGridCellAttr* DataGridTable::GetAttr(int row, int col,
         bgCol = wxColour(255, 208, 208);
     else if (info.rowInserted)
         bgCol = wxColour(235, 255, 200);
-    else if (info.fieldReadOnly)
+    else if (readOnlyM || info.fieldReadOnly)
         bgCol = getReadonlyColour();
     else
         bgCol = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW);
@@ -458,11 +455,7 @@ int DataGridTable::GetNumberRows()
 wxColour DataGridTable::getReadonlyColour()
 {
     static wxColour colourReadOnly;
-#if wxCHECK_VERSION(2, 8, 0)
     if (!colourReadOnly.IsOk())
-#else
-    if (!colourReadOnly.Ok())
-#endif
     {
         // first try to compute a colour that is between "white" and "gray"
         // (but use the actual system colours instead of hard-coded values)
@@ -513,7 +506,8 @@ wxString DataGridTable::getTableName()
     //       (together with PK/UNQ info)
     if (getStatementColCount() == 0)
         return wxEmptyString;
-    return std2wx(statementM->ColumnTable(1));
+    return std2wxIdentifier(statementM->ColumnTable(1),
+        databaseM->getCharsetConverter());
 }
 //-----------------------------------------------------------------------------
 void DataGridTable::getTableNames(wxArrayString& tables)
@@ -526,7 +520,8 @@ void DataGridTable::getTableNames(wxArrayString& tables)
     }
     for (int i = 0; i < colCount; i++)
     {
-        wxString tn(std2wx(statementM->ColumnTable(i+1)));
+        wxString tn(std2wxIdentifier(statementM->ColumnTable(i + 1),
+            databaseM->getCharsetConverter()));
         if (wxNOT_FOUND == tables.Index(tn))
         {
             // check if table exists in metadata
@@ -537,7 +532,8 @@ void DataGridTable::getTableNames(wxArrayString& tables)
             t->checkAndLoadColumns();
 
             // check if table's column is 'real'
-            wxString cn(std2wx(statementM->ColumnName(i+1)));
+            wxString cn(std2wxIdentifier(statementM->ColumnName(i + 1),
+                databaseM->getCharsetConverter()));
             for (MetadataCollection<Column>::iterator it = t->begin();
                 it != t->end(); ++it)
             {
@@ -567,10 +563,12 @@ void DataGridTable::getFields(const wxString& table,
     TempMap fields;
     for (int i = 0; i < colCount; i++)
     {
-        wxString tn(std2wx(statementM->ColumnTable(i+1)));
+        wxString tn(std2wxIdentifier(statementM->ColumnTable(i + 1),
+            databaseM->getCharsetConverter()));
         if (tn != table)
             continue;
-        wxString fn(std2wx(statementM->ColumnName(i+1)));
+        wxString fn(std2wxIdentifier(statementM->ColumnName(i + 1),
+            databaseM->getCharsetConverter()));
         // check if field exists in the table (and is not computed)
         for (MetadataCollection<Column>::iterator it = t->begin();
             it != t->end(); ++it)
@@ -650,22 +648,18 @@ wxString DataGridTable::GetValue(int row, int col)
     return cellValue;
 }
 //-----------------------------------------------------------------------------
-void DataGridTable::initialFetch(wxMBConv* conv)
+void DataGridTable::initialFetch(bool readonly)
 {
     Clear();
     allRowsFetchedM = false;
+    readOnlyM = readonly;
     canInsertRowsIsSetM = false;
     canInsertRowsM = false;
     maxRowToFetchM = 100;
 
-    if (conv)
-        charsetConverterM = conv;
-    else
-        charsetConverterM = wxConvCurrent;
-
     try
     {
-        rowsM.initialize(statementM, databaseM);
+        rowsM.initialize(statementM);
     }
     catch (IBPP::Exception& e)
     {
@@ -708,7 +702,7 @@ bool DataGridTable::isNumericColumn(int col)
 //-----------------------------------------------------------------------------
 bool DataGridTable::isReadonlyColumn(int col)
 {
-    return rowsM.isColumnReadonly(col);
+    return readOnlyM || rowsM.isColumnReadonly(col);
 }
 //-----------------------------------------------------------------------------
 bool DataGridTable::isValidCellPos(int row, int col)
