@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: column.cpp 1636 2008-02-17 22:53:37Z babuskov $
+  $Id: column.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -59,12 +59,10 @@ Column::Column()
 void Column::Init(bool notnull, wxString source, wxString computedSource,
     wxString collation, wxString defaultValue, bool hasDefault)
 {
-    source.Trim();        // right trim everything
-    collation.Trim();
     notnullM = notnull;
-    sourceM = source;
+    sourceM = source.Strip(wxString::both);
     computedSourceM = computedSource;
-    collationM = collation;
+    collationM = collation.Strip(wxString::both);
     defaultM = defaultValue;
     hasDefaultM = hasDefault;
 }
