@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: database.cpp 1704 2008-06-29 21:21:18Z babuskov $
+  $Id: database.cpp 1844 2009-04-06 19:08:21Z babuskov $
 
 */
 
@@ -38,6 +38,9 @@
     #pragma hdrstop
 #endif
 
+#include <wx/encconv.h>
+#include <wx/fontmap.h>
+
 #include <sstream>
 
 #include "config/Config.h"
@@ -56,6 +59,33 @@
 //-----------------------------------------------------------------------------
 using namespace std;
 //-----------------------------------------------------------------------------
+// CharacterSet class
+CharacterSet::CharacterSet(const wxString& name, int id, int bytesPerChar)
+    : nameM(name), idM(id), bytesPerCharM(bytesPerChar)
+{
+}
+//-----------------------------------------------------------------------------
+bool CharacterSet::operator< (const CharacterSet& other) const
+{
+    return nameM < other.nameM;
+}
+//-----------------------------------------------------------------------------
+int CharacterSet::getBytesPerChar() const
+{
+    return bytesPerCharM;
+}
+//-----------------------------------------------------------------------------
+int CharacterSet::getId() const
+{
+    return idM;
+}
+//-----------------------------------------------------------------------------
+wxString CharacterSet::getName() const
+{
+    return nameM;
+}
+//-----------------------------------------------------------------------------
+// Credentials class
 void Credentials::setCharset(wxString value)
 {
     charsetM = value;
@@ -96,76 +126,182 @@ wxString Credentials::getRole() const
     return roleM;
 }
 //-----------------------------------------------------------------------------
-int DatabaseInfo::getBuffers()
+int DatabaseInfo::getBuffers() const
 {
     return buffersM;
 }
 //-----------------------------------------------------------------------------
-wxString DatabaseInfo::getCreated()
+wxString DatabaseInfo::getCreated() const
 {
     return wxT("not supported");
 }
 //-----------------------------------------------------------------------------
-int DatabaseInfo::getDialect()
+int DatabaseInfo::getDialect() const
 {
     return dialectM;
 }
 //-----------------------------------------------------------------------------
-bool DatabaseInfo::getForcedWrites()
+bool DatabaseInfo::getForcedWrites() const
 {
     return forcedWritesM;
 }
 //-----------------------------------------------------------------------------
-int DatabaseInfo::getNextTransaction()
+int DatabaseInfo::getNextTransaction() const
 {
     return nextTransactionM;
 }
 //-----------------------------------------------------------------------------
-int DatabaseInfo::getODS()
+int DatabaseInfo::getODS() const
 {
     return odsM;
 }
 //-----------------------------------------------------------------------------
-int DatabaseInfo::getODSMinor()
+int DatabaseInfo::getODSMinor() const
 {
     return odsMinorM;
 }
 //-----------------------------------------------------------------------------
-int DatabaseInfo::getOldestTransaction()
+bool DatabaseInfo::getODSVersionIsHigherOrEqualTo(int versionMajor) const
+{
+    return odsM >= versionMajor;
+}
+//-----------------------------------------------------------------------------
+bool DatabaseInfo::getODSVersionIsHigherOrEqualTo(int versionMajor,
+    int versionMinor) const
+{
+    return odsM > versionMajor
+        || (odsM == versionMajor && odsMinorM >= versionMinor);
+}
+//-----------------------------------------------------------------------------
+int DatabaseInfo::getOldestTransaction() const
 {
     return oldestTransactionM;
 }
 //-----------------------------------------------------------------------------
-int DatabaseInfo::getPageSize()
+int DatabaseInfo::getPageSize() const
 {
     return pageSizeM;
 }
 //-----------------------------------------------------------------------------
-int DatabaseInfo::getPages()
+int DatabaseInfo::getPages() const
 {
     return pagesM;
 }
 //-----------------------------------------------------------------------------
-bool DatabaseInfo::getReadOnly()
+bool DatabaseInfo::getReadOnly() const
 {
     return readOnlyM;
 }
 //-----------------------------------------------------------------------------
-int DatabaseInfo::getSweep()
+int64_t DatabaseInfo::getSizeInBytes() const
+{
+    return (int64_t)getPages() * (int64_t)getPageSize();
+}
+//-----------------------------------------------------------------------------
+int DatabaseInfo::getSweep() const
 {
     return sweepM;
 }
 //-----------------------------------------------------------------------------
-void DatabaseInfo::loadInfo(const IBPP::Database* database)
+void DatabaseInfo::load(const IBPP::Database database)
 {
-    (*database)->Info(&odsM, &odsMinorM, &pageSizeM, &pagesM,
+    database->Info(&odsM, &odsMinorM, &pageSizeM, &pagesM,
         &buffersM, &sweepM, &forcedWritesM, &reserveM, &readOnlyM);
-    dialectM = (*database)->Dialect();
+    dialectM = database->Dialect();
+    loadTimeMillisM = ::wxGetLocalTimeMillis();
 }
 //-----------------------------------------------------------------------------
+void DatabaseInfo::reloadIfNecessary(const IBPP::Database database)
+{
+    wxLongLong millisNow = ::wxGetLocalTimeMillis();
+    // value may jump or even actually decrease, for instance on timezone
+    // change or when daylight saving time ends...
+    wxLongLong millisDelta = millisNow - loadTimeMillisM;
+    if (millisDelta >= 1000 || millisDelta <= -1000)
+        load(database);
+}
+//-----------------------------------------------------------------------------
+// DatabaseAuthenticationMode class
+DatabaseAuthenticationMode::DatabaseAuthenticationMode()
+    : modeM(UseSavedPassword)
+{
+}
+//-----------------------------------------------------------------------------
+int DatabaseAuthenticationMode::getMode() const
+{
+    return int(modeM);
+}
+//-----------------------------------------------------------------------------
+void DatabaseAuthenticationMode::setMode(int mode)
+{
+    switch (mode)
+    {
+        case UseSavedPassword:
+        case UseSavedEncryptedPwd:
+        case AlwaysEnterPassword:
+        case TrustedUser:
+            modeM = Mode(mode);
+            break;
+        default:
+            wxASSERT(false);
+    }
+}
+//-----------------------------------------------------------------------------
+wxString DatabaseAuthenticationMode::getConfigValue() const
+{
+    switch (modeM)
+    {
+        case UseSavedEncryptedPwd:
+            return wxT("encpwd");
+        case AlwaysEnterPassword:
+            return wxT("askpwd");
+        case TrustedUser:
+            return wxT("trusted");
+        default:
+            return wxT("pwd");
+    }
+}
+//-----------------------------------------------------------------------------
+void DatabaseAuthenticationMode::setConfigValue(const wxString& value)
+{
+    if (value == wxT("pwd"))
+        modeM = UseSavedPassword;
+    else if (value == wxT("encpwd"))
+        modeM = UseSavedEncryptedPwd;
+    else if (value == wxT("askpwd"))
+        modeM = AlwaysEnterPassword;
+    else if (value == wxT("trusted"))
+        modeM = TrustedUser;
+    else
+        wxASSERT(false);
+}
+//-----------------------------------------------------------------------------
+void DatabaseAuthenticationMode::setStoreEncryptedPassword()
+{
+    // ignore if old setting found after new mode has been set already
+    if (modeM == UseSavedPassword)
+        modeM = UseSavedEncryptedPwd;
+}
+//-----------------------------------------------------------------------------
+bool DatabaseAuthenticationMode::getAlwaysAskForPassword() const
+{
+    return modeM == AlwaysEnterPassword;
+}
+//-----------------------------------------------------------------------------
+bool DatabaseAuthenticationMode::getIgnoreUsernamePassword() const
+{
+    return modeM == TrustedUser;
+}
+//-----------------------------------------------------------------------------
+bool DatabaseAuthenticationMode::getUseEncryptedPassword() const
+{
+    return modeM == UseSavedEncryptedPwd;
+}
+//-----------------------------------------------------------------------------
+// Database class
 Database::Database()
-    : MetadataItem(), metadataLoaderM(0), connectedM(false), connectionCredentialsM(0),
-    storeEncryptedPasswordM(false), idM(0)
+    : MetadataItem(), metadataLoaderM(0), connectedM(false),
+        connectionCredentialsM(0), charsetConverterM(0), idM(0)
 {
     typeM = ntDatabase;
 
@@ -186,7 +322,7 @@ Database::Database()
 //-----------------------------------------------------------------------------
 Database::Database(const Database& rhs)
     : MetadataItem(rhs), databaseM(rhs.databaseM),
-        metadataLoaderM(0), connectedM(rhs.connectedM),
+        metadataLoaderM(0), connectedM(false), charsetConverterM(0),
         databaseCharsetM(rhs.databaseCharsetM), pathM(rhs.pathM),
         credentialsM(rhs.credentialsM), connectionCredentialsM(0),
         domainsM(rhs.domainsM), exceptionsM(rhs.exceptionsM),
@@ -194,7 +330,7 @@ Database::Database(const Database& rhs)
         proceduresM(rhs.proceduresM), rolesM(rhs.rolesM), tablesM(rhs.tablesM),
         sysTablesM(rhs.sysTablesM), triggersM(rhs.triggersM),
         viewsM(rhs.viewsM), collationsM(rhs.collationsM), idM(rhs.idM),
-        storeEncryptedPasswordM(rhs.storeEncryptedPasswordM)
+        authenticationModeM(rhs.authenticationModeM)
 {
     if (rhs.connectionCredentialsM)
         connectionCredentialsM = new Credentials(*rhs.connectionCredentialsM);
@@ -214,6 +350,7 @@ Database::Database(const Database& rhs)
 Database::~Database()
 {
     resetCredentials();
+    delete charsetConverterM;
 }
 //-----------------------------------------------------------------------------
 void Database::prepareTemporaryCredentials()
@@ -294,14 +431,13 @@ wxString Database::loadDomainNameForColumn(wxString table, wxString field)
         "select rdb$field_source from rdb$relation_fields"
         " where rdb$relation_name = ? and rdb$field_name = ?"
     );
-    st1->Set(1, wx2std(table));
-    st1->Set(2, wx2std(field));
+    st1->Set(1, wx2std(table, getCharsetConverter()));
+    st1->Set(2, wx2std(field, getCharsetConverter()));
     st1->Execute();
     st1->Fetch();
     std::string domain;
     st1->Get(1, domain);
-    domain.erase(domain.find_last_not_of(" ") + 1);
-    return std2wx(domain);
+    return std2wxIdentifier(domain, getCharsetConverter());
 }
 //-----------------------------------------------------------------------------
 void Database::getDatabaseTriggers(std::vector<Trigger *>& list)
@@ -319,21 +455,34 @@ void Database::getDatabaseTriggers(std::vector<Trigger *>& list)
     {
         std::string name;
         st1->Get(1, name);
-        name.erase(name.find_last_not_of(" ") + 1);
         Trigger* t = dynamic_cast<Trigger*>(findByNameAndType(ntTrigger,
-            std2wx(name)));
+            std2wxIdentifier(name, getCharsetConverter())));
         if (t)
             list.push_back(t);
     }
 }
 //-----------------------------------------------------------------------------
+CharacterSet Database::getCharsetById(int id)
+{
+    // if it contains both charset and collation as 2 bytes
+    id %= 256;
+
+    loadCollations();
+    for (std::multimap<CharacterSet, wxString>::iterator it =
+        collationsM.begin(); it != collationsM.end(); ++it)
+    {
+        if ((*it).first.getId() == id)
+            return (*it).first;
+    }
+    throw FRError(wxString::Format(_("Character set ID %d not found."), id));
+}
+//-----------------------------------------------------------------------------
 //! returns all collations for a given charset
-std::vector<wxString> Database::getCollations(wxString charset)
+std::vector<wxString> Database::getCollations(const wxString& charset)
 {
     loadCollations();
     std::vector<wxString> temp;
-    std::multimap<wxString, wxString>::iterator low, high;
-
+    std::multimap<CharacterSet, wxString>::iterator low, high;
     high = collationsM.upper_bound(charset);
     for (low = collationsM.lower_bound(charset); low != high; ++low)
         temp.push_back((*low).second);
@@ -350,7 +499,7 @@ Domain* Database::loadMissingDomain(wxString name)
         " left outer join rdb$types t on f.rdb$field_type=t.rdb$type"
         " where t.rdb$field_name='RDB$FIELD_TYPE' and f.rdb$field_name = ?"
     );
-    st1->Set(1, wx2std(name));
+    st1->Set(1, wx2std(name, getCharsetConverter()));
     st1->Execute();
     if (st1->Fetch())
     {
@@ -375,14 +524,14 @@ void Database::fillVector(std::vector<wxString>& list, wxString sql)
     MetadataLoader* loader = getMetadataLoader();
     MetadataLoaderTransaction tr(loader);
 
-    IBPP::Statement& st1 = loader->getStatement(wx2std(sql));
+    IBPP::Statement& st1 = loader->getStatement(wx2std(sql,
+        getCharsetConverter()));
     st1->Execute();
     while (st1->Fetch())
     {
         std::string s;
         st1->Get(1, s);
-        s.erase(s.find_last_not_of(" ") + 1); // trim
-        list.push_back(std2wx(s));
+        list.push_back(std2wxIdentifier(s, getCharsetConverter()));
     }
 }
 //-----------------------------------------------------------------------------
@@ -406,7 +555,8 @@ void Database::loadCollations()
     MetadataLoaderTransaction tr(loader);
 
     IBPP::Statement& st1 = loader->getStatement(
-        "select c.rdb$character_set_name, k.rdb$collation_name "
+        "select c.rdb$character_set_name, k.rdb$collation_name, "
+        " c.RDB$CHARACTER_SET_ID, c.RDB$BYTES_PER_CHARACTER "
         " from rdb$character_sets c"
         " left outer join rdb$collations k "
         "   on c.rdb$character_set_id = k.rdb$character_set_id "
@@ -414,13 +564,17 @@ void Database::loadCollations()
     st1->Execute();
     while (st1->Fetch())
     {
-        std::string charset, collation;
-        st1->Get(1, charset);
-        st1->Get(2, collation);
-        charset.erase(charset.find_last_not_of(" ") + 1);
-        collation.erase(collation.find_last_not_of(" ") + 1);
-        collationsM.insert(std::multimap<wxString, wxString>::value_type(
-            std2wx(charset), std2wx(collation)));
+        std::string s;
+        st1->Get(1, s);
+        wxString charset(std2wxIdentifier(s, getCharsetConverter()));
+        st1->Get(2, s);
+        wxString collation(std2wxIdentifier(s, getCharsetConverter()));
+        int charsetId, bytesPerChar;
+        st1->Get(3, &charsetId);
+        st1->Get(4, &bytesPerChar);
+        CharacterSet cs(charset, charsetId, bytesPerChar);
+        collationsM.insert(std::multimap<CharacterSet, wxString>::value_type(
+            cs, collation));
     }
 }
 //-----------------------------------------------------------------------------
@@ -431,16 +585,15 @@ wxString Database::getTableForIndex(wxString indexName)
 
     IBPP::Statement& st1 = loader->getStatement(
         "SELECT rdb$relation_name from rdb$indices where rdb$index_name = ?");
-    st1->Set(1, wx2std(indexName));
+    st1->Set(1, wx2std(indexName, getCharsetConverter()));
     st1->Execute();
 
     wxString tableName;
     if (st1->Fetch())
     {
-        std::string retval;
-        st1->Get(1, retval);
-        retval.erase(retval.find_last_not_of(" ") + 1);
-        tableName = std2wx(retval);
+        std::string s;
+        st1->Get(1, s);
+        tableName = std2wxIdentifier(s, getCharsetConverter());
     }
     return tableName;
 }
@@ -471,14 +624,14 @@ void Database::loadObjects(NodeType type, ProgressIndicator* indicator)
     MetadataLoaderTransaction tr(loader);
     SubjectLocker lock(this);
 
-    IBPP::Statement& st1 = loader->getStatement(wx2std(getLoadingSql(type)));
+    IBPP::Statement& st1 = loader->getStatement(wx2std(getLoadingSql(type),
+        getCharsetConverter()));
     st1->Execute();
     while (st1->Fetch())
     {
         std::string name;
         st1->Get(1, name);
-        name.erase(name.find_last_not_of(" ") + 1);
-        addObject(type, std2wx(name));
+        addObject(type, std2wxIdentifier(name, getCharsetConverter()));
 
         if (indicator && indicator->isCanceled())
             break;
@@ -556,13 +709,19 @@ MetadataItem* Database::findByNameAndType(NodeType nt, wxString name)
 Relation* Database::findRelation(const Identifier& name)
 {
     for (MetadataCollection<Table>::iterator it = tablesM.begin();
-        it != tablesM.end(); it++)
+        it != tablesM.end(); ++it)
     {
         if ((*it).getIdentifier().equals(name))
             return &(*it);
     }
     for (MetadataCollection<View>::iterator it = viewsM.begin();
-        it != viewsM.end(); it++)
+        it != viewsM.end(); ++it)
+    {
+        if ((*it).getIdentifier().equals(name))
+            return &(*it);
+    }
+    for (MetadataCollection<Table>::iterator it = sysTablesM.begin();
+        it != sysTablesM.end(); ++it)
     {
         if ((*it).getIdentifier().equals(name))
             return &(*it);
@@ -837,11 +996,22 @@ void Database::connect(wxString password, ProgressIndicator* indicator)
 
     try
     {
+        createCharsetConverter();
+
         if (indicator)
             indicator->initProgressIndeterminate(wxT("Establishing connection..."));
-        databaseM = IBPP::DatabaseFactory("", wx2std(getConnectionString()),
-            wx2std(getUsername()), wx2std(password), wx2std(getRole()),
-            wx2std(getConnectionCharset()), "");
+
+        if (authenticationModeM.getIgnoreUsernamePassword())
+        {
+            databaseM = IBPP::DatabaseFactory("", wx2std(getConnectionString()),
+                "", "", wx2std(getRole()), wx2std(getConnectionCharset()), "");
+        }
+        else
+        {
+            databaseM = IBPP::DatabaseFactory("", wx2std(getConnectionString()),
+                wx2std(getUsername()), wx2std(password), wx2std(getRole()),
+                wx2std(getConnectionCharset()), "");
+        }
 
         databaseM->Connect();
         connectedM = true;
@@ -866,9 +1036,9 @@ void Database::connect(wxString password, ProgressIndicator* indicator)
             st1->Execute();
             if (st1->Fetch())
             {
-                std::string databaseCharset;
-                st1->Get(1, databaseCharset);
-                databaseCharsetM = std2wx(databaseCharset).Strip();
+                std::string s;
+                st1->Get(1, s);
+                databaseCharsetM = std2wxIdentifier(s, getCharsetConverter());
             }
 
             // load metadata information
@@ -913,7 +1083,7 @@ void Database::connect(wxString password, ProgressIndicator* indicator)
             disconnect();
 
         if (connectedM)
-            databaseInfoM.loadInfo(&databaseM);
+            databaseInfoM.load(databaseM);
     }
     catch (...)
     {
@@ -1095,6 +1265,18 @@ wxString Database::getConnectionCharset() const
         return credentialsM.getCharset();
 }
 //-----------------------------------------------------------------------------
+wxString Database::getConnectionInfoString() const
+{
+    wxString info;
+    if (authenticationModeM.getIgnoreUsernamePassword())
+        info = _("[Trusted user]");
+    else
+        info = getUsername();
+    info += wxT("@") + getConnectionString() + wxT(" (")
+        + getConnectionCharset() + wxT(")");
+    return info;
+}
+//-----------------------------------------------------------------------------
 bool Database::usesDifferentConnectionCharset() const
 {
     wxString charset(getConnectionCharset().Upper());
@@ -1132,15 +1314,15 @@ wxString Database::getDecryptedPassword() const
     if (raw.IsEmpty())
         return wxEmptyString;
 
-    if (storeEncryptedPasswordM)
+    if (authenticationModeM.getUseEncryptedPassword())
         return decryptPassword(raw, getUsername() + getConnectionString());
     else
         return raw;
 }
 //-----------------------------------------------------------------------------
-bool Database::getStoreEncryptedPassword() const
+DatabaseAuthenticationMode& Database::getAuthenticationMode()
 {
-    return storeEncryptedPasswordM;
+    return authenticationModeM;
 }
 //-----------------------------------------------------------------------------
 wxString Database::getRole() const
@@ -1187,30 +1369,17 @@ void Database::setRawPassword(wxString value)
 //-----------------------------------------------------------------------------
 void Database::setEncryptedPassword(wxString value)
 {
-    // temporary connection
+    // temporary credentials -> use password as entered
     if (connectionCredentialsM)
     {
         connectionCredentialsM->setPassword(value);
         return;
     }
-    if (value.IsEmpty())
-    {
-        credentialsM.setPassword(value);
-        return;
-    }
 
-    if (storeEncryptedPasswordM)
-    {
-        credentialsM.setPassword(encryptPassword(value,
-            getUsername()+getConnectionString()));
-    }
-    else
-        credentialsM.setPassword(value);
-}
-//-----------------------------------------------------------------------------
-void Database::setStoreEncryptedPassword(bool value)
-{
-    storeEncryptedPasswordM = value;
+    // password must not be empty to be encrypted
+    if (authenticationModeM.getUseEncryptedPassword() && !value.IsEmpty())
+        value = encryptPassword(value, getUsername() + getConnectionString());
+    credentialsM.setPassword(value);
 }
 //-----------------------------------------------------------------------------
 void Database::setRole(wxString value)
@@ -1270,9 +1439,16 @@ void Database::setId(int id)
     idM = id;
 }
 //-----------------------------------------------------------------------------
-DatabaseInfo* Database::getInfo() const
+const DatabaseInfo& Database::getInfo()
 {
-    return const_cast<DatabaseInfo*>(&databaseInfoM);
+    databaseInfoM.reloadIfNecessary(databaseM);
+    return databaseInfoM;
+}
+//-----------------------------------------------------------------------------
+void Database::loadInfo()
+{
+    databaseInfoM.load(databaseM);
+    notifyObservers();
 }
 //-----------------------------------------------------------------------------
 bool Database::showSysTables()
@@ -1286,3 +1462,54 @@ bool Database::showSysTables()
     return b;
 }
 //-----------------------------------------------------------------------------
+wxString mapConnectionCharsetToSystemCharset(const wxString& connectionCharset)
+{
+    wxString charset(connectionCharset.Upper().Trim());
+    charset.Trim(false);
+
+    // fixes hang when character set name empty (invalid encoding is returned)
+    if (charset.empty())
+        charset = wxT("NONE");
+
+    // Firebird charsets WIN125X need to be replaced with either
+    // WINDOWS125X or CP125X - we take the latter
+    if (charset.Mid(0, 5) == wxT("WIN12"))
+        return wxT("CP12") + charset.Mid(5);
+
+    // Firebird charsets ISO8859_X
+    if (charset.Mid(0, 8) == wxT("ISO8859_"))
+        return wxT("ISO-8859-") + charset.Mid(8);
+
+    // all other mappings need to be added here...
+    struct CharsetMapping { const wxChar* connCS; const wxChar* convCS; };
+    static const CharsetMapping mappings[] = {
+        { wxT("UTF8"), wxT("UTF-8") }, { wxT("UNICODE_FSS"), wxT("UTF-8") }
+    };
+    int mappingCount = sizeof(mappings) / sizeof(CharsetMapping);
+    for (int i = 0; i < mappingCount; i++)
+    {
+        if (mappings[i].connCS == charset)
+            return mappings[i].convCS;
+    }
+
+    return charset;
+}
+//-----------------------------------------------------------------------------
+void Database::createCharsetConverter()
+{
+    delete charsetConverterM;
+    charsetConverterM = 0;
+
+    wxString cs(mapConnectionCharsetToSystemCharset(getConnectionCharset()));
+    wxFontEncoding fe = wxFontMapperBase::Get()->CharsetToEncoding(cs, false);
+    if (fe != wxFONTENCODING_SYSTEM)
+        charsetConverterM = new wxCSConv(fe);
+}
+//-----------------------------------------------------------------------------
+wxMBConv* Database::getCharsetConverter() const
+{
+    if (charsetConverterM)
+        return charsetConverterM;
+    return wxConvCurrent;
+}
+//-----------------------------------------------------------------------------
