@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: metadataitem.h 1631 2008-02-02 22:25:30Z mapopa $
+  $Id: metadataitem.h 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -66,6 +66,21 @@ private:
 protected:
     Identifier identifierM;
     NodeType typeM;
+
+    template <class T>
+    T* getParentObjectByType() const
+    {
+        MetadataItem *m = getParent();
+        while (m)
+        {
+            T* t = dynamic_cast<T*>(m);
+            if (t)
+                return t;
+            m = m->getParent();
+        }
+        return 0;
+    }
+
     MetadataItem* getParentObjectOfType(NodeType type) const;
 
     virtual void loadDescription();
