@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: procedure.cpp 1723 2008-07-23 12:04:56Z babuskov $
+  $Id: procedure.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -189,31 +189,33 @@ void Procedure::loadParameters()
     std::string sql(
         "select p.rdb$parameter_name, p.rdb$field_source, p.rdb$parameter_type"
     );
-    DatabaseInfo *dbi = d->getInfo();
-    int ods = dbi->getODS();
-    int minor = dbi->getODSMinor();
-    if (ods > 11 || ods == 11 && minor > 0)
+    if (d->getInfo().getODSVersionIsHigherOrEqualTo(11, 1))
         sql += ", RDB$PARAMETER_MECHANISM ";
     else
         sql += ", -1 ";
     sql +=  " from rdb$procedure_parameters p"
             " where p.rdb$PROCEDURE_name = ? "
             " order by p.rdb$parameter_type, rdb$PARAMETER_number ";
+
     IBPP::Statement st1 = loader->getStatement(sql);
-    st1->Set(1, wx2std(getName_()));
+    st1->Set(1, wx2std(getName_(), d->getCharsetConverter()));
     st1->Execute();
 
     while (st1->Fetch())
     {
-        std::string column_name, source;
+        std::string s;
+        st1->Get(1, s);
+        wxString column_name(std2wxIdentifier(s, d->getCharsetConverter()));
+        st1->Get(2, s);
+        wxString source(std2wxIdentifier(s, d->getCharsetConverter()));
+
         short partype, mechanism = -1;
-        st1->Get(1, column_name);
-        st1->Get(2, source);
         st1->Get(3, &partype);
         if (!st1->IsNull(4))
             st1->Get(4, mechanism);
-        Parameter p(std2wx(source), partype, mechanism);
-        p.setName_(std2wx(column_name));
+
+        Parameter p(source, partype, mechanism);
+        p.setName_(column_name);
         Parameter* pp = parametersM.add(p);
         pp->setParent(this);
     }
@@ -230,12 +232,12 @@ wxString Procedure::getOwner()
 
     IBPP::Statement st1 = loader->getStatement(
         "select rdb$owner_name from rdb$procedures where rdb$procedure_name = ?");
-    st1->Set(1, wx2std(getName_()));
+    st1->Set(1, wx2std(getName_(), d->getCharsetConverter()));
     st1->Execute();
     st1->Fetch();
     std::string name;
     st1->Get(1, name);
-    return std2wx(name).Trim();
+    return std2wxIdentifier(name, d->getCharsetConverter());
 }
 //-----------------------------------------------------------------------------
 wxString Procedure::getSource()
@@ -246,11 +248,11 @@ wxString Procedure::getSource()
 
     IBPP::Statement st1 = loader->getStatement(
         "select rdb$procedure_source from rdb$procedures where rdb$procedure_name = ?");
-    st1->Set(1, wx2std(getName_()));
+    st1->Set(1, wx2std(getName_(), d->getCharsetConverter()));
     st1->Execute();
     st1->Fetch();
     wxString source;
-    readBlob(st1, 1, source);
+    readBlob(st1, 1, source, d->getCharsetConverter());
     source.Trim(false);     // remove leading whitespace
     return source;
 }
@@ -464,7 +466,7 @@ std::vector<Privilege>* Procedure::getPrivileges()
         "where RDB$RELATION_NAME = ? and rdb$object_type = 5 "
         "order by rdb$user, rdb$user_type, rdb$privilege"
     );
-    st1->Set(1, wx2std(getName_()));
+    st1->Set(1, wx2std(getName_(), d->getCharsetConverter()));
     st1->Execute();
     std::string lastuser;
     int lasttype = -1;
@@ -482,14 +484,15 @@ std::vector<Privilege>* Procedure::getPrivileges()
         st1->Get(6, field);
         if (!pr || user != lastuser || usertype != lasttype)
         {
-            Privilege p(this, std2wx(user).Strip(), usertype);
+            Privilege p(this, std2wxIdentifier(user, d->getCharsetConverter()),
+                usertype);
             privilegesM.push_back(p);
             pr = &privilegesM.back();
             lastuser = user;
             lasttype = usertype;
         }
-        pr->addPrivilege(privilege[0], std2wx(grantor).Strip(),
-            grantoption == 1);
+        pr->addPrivilege(privilege[0],
+            std2wx(grantor, d->getCharsetConverter()), grantoption == 1);
     }
     return &privilegesM;
 }
