@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: relation.cpp 1709 2008-07-06 19:11:06Z babuskov $
+  $Id: relation.cpp 1838 2009-03-13 18:12:08Z babuskov $
 
 */
 
@@ -100,23 +100,21 @@ void Relation::loadInfo()
     MetadataLoader* loader = d->getMetadataLoader();
     MetadataLoaderTransaction tr(loader);
 
-    DatabaseInfo *dbi = d->getInfo();
-    int ods = dbi->getODS();
-    int minor = dbi->getODSMinor();
-    std::string sql;
-    if (ods < 11 || ods == 11 && minor < 1)
-        sql = "select rdb$owner_name, 0 from rdb$relations where rdb$relation_name = ?";
+    std::string sql("select rdb$owner_name, ");
+    if (d->getInfo().getODSVersionIsHigherOrEqualTo(11, 1))
+        sql += "rdb$relation_type";
     else
-        sql = "select rdb$owner_name, rdb$relation_type from rdb$relations where rdb$relation_name = ?";
+        sql += "0";
+    sql += " from rdb$relations where rdb$relation_name = ?";
 
     IBPP::Statement& st1 = loader->getStatement(sql);
-    st1->Set(1, wx2std(getName_()));
+    st1->Set(1, wx2std(getName_(), d->getCharsetConverter()));
     st1->Execute();
     if (st1->Fetch())
     {
         std::string name;
         st1->Get(1, name);
-        ownerM = std2wx(name).Trim();
+        ownerM = std2wxIdentifier(name, d->getCharsetConverter());
         st1->Get(2, relationTypeM);
         relationInfoLoadedM = true;
     }
@@ -168,20 +166,23 @@ void Relation::loadColumns()
         " where r.rdb$relation_name = ?"
         " order by r.rdb$field_position"
     );
-    st1->Set(1, wx2std(getName_()));
+    st1->Set(1, wx2std(getName_(), d->getCharsetConverter()));
     st1->Execute();
     while (st1->Fetch())
     {
-        std::string name, source, collation;
+        std::string s, coll;
+        st1->Get(1, s);
+        wxString fname(std2wxIdentifier(s, d->getCharsetConverter()));
+        st1->Get(3, s);
+        wxString source(std2wxIdentifier(s, d->getCharsetConverter()));
+        if (!st1->IsNull(4))
+            st1->Get(4, coll);
+        wxString collation(std2wxIdentifier(coll, d->getCharsetConverter()));
         wxString computedSrc, defaultSrc;
-        st1->Get(1, name);
-        st1->Get(3, source);
-        st1->Get(4, collation);
-        readBlob(st1, 5, computedSrc);
-
+        readBlob(st1, 5, computedSrc, d->getCharsetConverter());
         if (!st1->IsNull(6))
         {
-            readBlob(st1, 6, defaultSrc);
+            readBlob(st1, 6, defaultSrc, d->getCharsetConverter());
             // Some users reported two spaces before DEFAULT word in source
             // Perhaps some other tools can put garbage here? Should we
             // parse it as SQL to clean up comments, whitespace, etc?
@@ -189,10 +190,10 @@ void Relation::loadColumns()
         }
 
         Column *cc = columnsM.add();
-        cc->setName_(std2wx(name));
+        cc->setName_(fname);
         cc->setParent(this);
-        cc->Init(!st1->IsNull(2), std2wx(source),
-            computedSrc, std2wx(collation), defaultSrc, !st1->IsNull(6));
+        cc->Init(!st1->IsNull(2), source,  computedSrc, collation,
+            defaultSrc, !st1->IsNull(6));
     }
     notifyObservers();
 }
@@ -237,25 +238,28 @@ void Relation::getDependentChecks(std::vector<CheckConstraint>& checks)
         "and t.rdb$trigger_type = 1 and d.rdb$field_name is null "
     );
 
-    st1->Set(1, wx2std(getName_()));
+    st1->Set(1, wx2std(getName_(), d->getCharsetConverter()));
     st1->Execute();
     while (st1->Fetch())
     {
+        std::string s;
+        st1->Get(1, s);
+        wxString cname(std2wxIdentifier(s, d->getCharsetConverter()));
+        st1->Get(2, s);
+        wxString table(std2wxIdentifier(s, d->getCharsetConverter()));
+
         wxString source;
-        std::string table, cname;
-        st1->Get(1, cname);
-        st1->Get(2, table);
-        readBlob(st1, 3, source);
-        wxString consname = std2wx(cname).Strip();
-        Table *tab = dynamic_cast<Table *>(d->findByNameAndType(ntTable,
-            std2wx(table).Strip()));
+        readBlob(st1, 3, source, d->getCharsetConverter());
+
+        Table* tab = dynamic_cast<Table*>(d->findByNameAndType(ntTable,
+            table));
         if (!tab)
             continue;
 
         // check if it exists
         std::vector<CheckConstraint>::iterator it;
         for (it = checks.begin(); it != checks.end(); ++it)
-            if ((*it).getTable() == tab && (*it).getName_() == consname)
+            if ((*it).getTable() == tab && (*it).getName_() == cname)
                 break;
 
         if (it != checks.end())     // already there
@@ -263,7 +267,7 @@ void Relation::getDependentChecks(std::vector<CheckConstraint>& checks)
 
         CheckConstraint c;
         c.setParent(tab);
-        c.setName_(consname);
+        c.setName_(cname);
         c.sourceM = source;
         checks.push_back(c);
     }
@@ -398,8 +402,11 @@ wxString Relation::getRebuildSql()
                     for (std::vector<ForeignKey>::iterator i2 = fk->begin();
                         i2 != fk->end(); ++i2)
                     {
-                        if ((*i2).referencedTableM == getName_())
+                        if ((*i2).referencedTableM == getName_() &&
+                            t1 != (*i2).getTable())
+                        {
                             fkeys.insert(fkeys.end(), (*i2));
+                        }
                     }
                 }
             }
@@ -513,7 +520,7 @@ std::vector<Privilege>* Relation::getPrivileges()
         "where RDB$RELATION_NAME = ? and rdb$object_type = 0 "
         "order by rdb$user, rdb$user_type, rdb$grant_option, rdb$privilege"
     );
-    st1->Set(1, wx2std(getName_()));
+    st1->Set(1, wx2std(getName_(), d->getCharsetConverter()));
     st1->Execute();
     std::string lastuser;
     int lasttype = -1;
@@ -531,14 +538,16 @@ std::vector<Privilege>* Relation::getPrivileges()
         st1->Get(6, field);
         if (!pr || user != lastuser || usertype != lasttype)
         {
-            Privilege p(this, std2wx(user).Strip(), usertype);
+            Privilege p(this, std2wx(user, d->getCharsetConverter()).Strip(),
+                usertype);
             privilegesM.push_back(p);
             pr = &privilegesM.back();
             lastuser = user;
             lasttype = usertype;
         }
-        pr->addPrivilege(privilege[0], std2wx(grantor).Strip(),
-            grantoption == 1, std2wx(field).Strip());
+        pr->addPrivilege(privilege[0],
+            std2wxIdentifier(grantor, d->getCharsetConverter()),
+            grantoption == 1, std2wxIdentifier(field, d->getCharsetConverter()));
     }
     return &privilegesM;
 }
@@ -556,15 +565,14 @@ void Relation::getTriggers(std::vector<Trigger *>& list,
         "select rdb$trigger_name from rdb$triggers where rdb$relation_name = ? "
         "order by rdb$trigger_sequence"
     );
-    st1->Set(1, wx2std(getName_()));
+    st1->Set(1, wx2std(getName_(), d->getCharsetConverter()));
     st1->Execute();
     while (st1->Fetch())
     {
         std::string name;
         st1->Get(1, name);
-        name.erase(name.find_last_not_of(" ") + 1);
         Trigger* t = dynamic_cast<Trigger*>(d->findByNameAndType(ntTrigger,
-            std2wx(name)));
+            std2wxIdentifier(name, d->getCharsetConverter())));
         if (t && t->getFiringTime() == beforeOrAfter)
             list.push_back(t);
     }
