@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: root.cpp 1631 2008-02-02 22:25:30Z mapopa $
+  $Id: root.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -168,8 +168,10 @@ bool Root::parseDatabase(Server* server, wxXmlNode* xmln)
             database->setUsername(value);
         else if (xmln->GetName() == wxT("password"))
             database->setRawPassword(value);
-        else if (xmln->GetName() == wxT("encrypted"))
-            database->setStoreEncryptedPassword(value == wxT("1"));
+        else if (xmln->GetName() == wxT("encrypted") && value == wxT("1"))
+            database->getAuthenticationMode().setStoreEncryptedPassword();
+        else if (xmln->GetName() == wxT("authentication"))
+            database->getAuthenticationMode().setConfigValue(value);
         else if (xmln->GetName() == wxT("role"))
             database->setRole(value);
         else if (xmln->GetName() == wxT("id"))
@@ -184,6 +186,7 @@ bool Root::parseDatabase(Server* server, wxXmlNode* xmln)
             }
         }
     }
+
     // make sure the database has an Id before Root::save() is called,
     // otherwise a new Id will be generated then, but the generator value
     // will not be stored because it's at the beginning of the file.
@@ -336,9 +339,9 @@ bool Root::save()
             rsAddChildNode(dbn, wxT("charset"), itdb->getConnectionCharset());
             rsAddChildNode(dbn, wxT("username"), itdb->getUsername());
             rsAddChildNode(dbn, wxT("password"), itdb->getRawPassword());
-            rsAddChildNode(dbn, wxT("encrypted"),
-                (itdb->getStoreEncryptedPassword() ? wxT("1") : wxT("0")));
             rsAddChildNode(dbn, wxT("role"), itdb->getRole());
+            rsAddChildNode(dbn, wxT("authentication"),
+                itdb->getAuthenticationMode().getConfigValue());
         }
     }
     if (!doc.Save(getFileName()))
