@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2008 The FlameRobin Development Team
+  Copyright (c) 2004-2009 The FlameRobin Development Team
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -21,7 +21,7 @@
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
-  $Id: view.cpp 1631 2008-02-02 22:25:30Z mapopa $
+  $Id: view.cpp 1836 2009-02-14 11:22:13Z mghie $
 
 */
 
@@ -68,7 +68,7 @@ wxString View::getSource()
     st1->Execute();
     st1->Fetch();
     wxString source;
-    readBlob(st1, 1, source);
+    readBlob(st1, 1, source, d->getCharsetConverter());
     return source;
 }
 //-----------------------------------------------------------------------------
